@@ -1,4 +1,4 @@
-### Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+### Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
 ###
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@
 
 use strict;
 
-use Locale::gettext;
 use JSON;
 use MSDP;
 
@@ -35,7 +34,7 @@ our $__helpfile;
 our @PLUGINDIRS;
 
 # Convenience wrapper
-sub _ { return gettext($_[0]); }
+sub _ { return ::gettext($_[0]); }
 
 {
   package World;
@@ -189,7 +188,7 @@ sub _ { return gettext($_[0]); }
 
   sub _listobject {
     my $self = shift;
-    my ($target, $function, $objnum, $objname, $extrafirstarg) = @_;
+    my ($target, $function, $objnum, $extrafirstarg) = @_;
 
     if (defined($target)) {
       if ($target =~ /^\d+$/) {
@@ -204,7 +203,7 @@ sub _ { return gettext($_[0]); }
                                             0,
                                             $extrafirstarg);
         if (scalar @found == 0) {
-          $self->echonl(sprintf(_('No such %s'), $objname));
+          $self->echonl($self->_getnosuchmsg($objnum));
         } else {
           foreach (@found) {
             if ($extrafirstarg) {
@@ -230,10 +229,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, '_listtrigger', 0, _('trigger'));
+        $self->_listobject($_, '_listtrigger', 0);
       }
     } else {
-      $self->_listobject(undef,  '_listtrigger', 0, _('trigger'));
+      $self->_listobject(undef,  '_listtrigger', 0);
     }
   }
 
@@ -243,10 +242,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, '_listalias', 1, _('alias'));
+        $self->_listobject($_, '_listalias', 1);
       }
     } else {
-      $self->_listobject(undef, '_listalias', 1, _('alias'));
+      $self->_listobject(undef, '_listalias', 1);
     }
   }
 
@@ -256,10 +255,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, '_listmacro', 2, _('macro'));
+        $self->_listobject($_, '_listmacro', 2);
       }
     } else {
-      $self->_listobject(undef, '_listmacro', 2, _('macro'));
+      $self->_listobject(undef, '_listmacro', 2);
     }
   }
 
@@ -269,10 +268,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, '_listtimer', 3, _('timer'));
+        $self->_listobject($_, '_listtimer', 3);
       }
     } else {
-      $self->_listobject(undef, '_listtimer', 3, _('timer'));
+      $self->_listobject(undef, '_listtimer', 3);
     }
   }
 
@@ -283,10 +282,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, '_listhook', 4, _('hook'), $event);
+        $self->_listobject($_, '_listhook', 4, $event);
       }
     } else {
-      $self->_listobject(undef, '_listhook', 4, _('hook'), $event);
+      $self->_listobject(undef, '_listhook', 4, $event);
     }
   }
 
@@ -375,7 +374,7 @@ sub _ { return gettext($_[0]); }
     my $name  = shift;
 
     my @found = $self->_getobjectnumber($name,
-                                        4,    # Timer
+                                        4,    # Hook
                                         0,    # By name
                                         $event);
     return @found;
@@ -387,84 +386,68 @@ sub _ { return gettext($_[0]); }
     my ($target,
         $function,
         $objnum,
-        $objname,
-        $objnameplural,
         $extrafirstarg) = @_;
     my $deleted = 0;
 
-    if (defined($target)) {
-      if ($target =~ /^\d+$/) {
-        if ($extrafirstarg) {
-          eval("\$deleted += \$self->_$function(\$extrafirstarg, $target)");
-        } else {
-          eval("\$deleted += \$self->_$function($target)");
-        }
-        if (!$deleted) {
-          $self->echonl(sprintf(_('No such %s.'), $objname));
-        }
-      } else {
-        my @found = reverse($self->_getobjectnumber($target,
-                                                    $objnum,
-                                                    0,
-                                                    $extrafirstarg));
-        if (scalar @found == 0) {
-          $self->echonl(sprintf(_('No such %s.'), $objname));
-        } else {
-          foreach (@found) {
-            if ($extrafirstarg) {
-              eval("\$deleted += \$self->_$function(\$extrafirstarg, $_)");
-            } else {
-              eval("\$deleted += \$self->_$function($_)");
-            }
-          }
-        }
-      }
+    if (!defined($target)) {
+      $self->echonl(sprintf(_('%s: Too few arguments.'), $function));
+      return undef;
+    }
 
-      unless ($self->{SILENT}) {
-        if (!$deleted) {
-          $self->echonl(sprintf(_('No %s deleted.'), $objnameplural));
-        } elsif ($deleted == 1) {
-          $self->echonl(sprintf(_('One %s deleted.'), $objname));
-        } else {
-          $self->echonl(sprintf(_('%d %s deleted.'), $deleted, $objnameplural));
-        }
+    if ($target =~ /^\d+$/) {
+      if ($extrafirstarg) {
+        eval("\$deleted += \$self->_$function(\$extrafirstarg, $target)");
+      } else {
+        eval("\$deleted += \$self->_$function($target)");
       }
     } else {
-      $self->echonl(sprintf(_('%s: Too few arguments.'), $function));
-      $deleted = undef;
+      my @found = reverse($self->_getobjectnumber($target,
+                                                  $objnum,
+                                                  0,
+                                                  $extrafirstarg));
+      foreach (@found) {
+        if ($extrafirstarg) {
+          eval("\$deleted += \$self->_$function(\$extrafirstarg, $_)");
+        } else {
+          eval("\$deleted += \$self->_$function($_)");
+        }
+      }
+    }
+
+    unless ($self->{SILENT}) {
+      $self->echonl($self->_getdelmsg($deleted, $objnum));
     }
 
     return $deleted;
   }
 
-
   sub deltrigger {
     my $self = shift;
-    return $self->_delobject($_[0], 'deltrigger', 0, _('trigger'), _('triggers'));
+    return $self->_delobject($_[0], 'deltrigger', 0);
   }
 
 
   sub delalias {
     my $self = shift;
-    return $self->_delobject($_[0], 'delalias', 1, _('alias'), _('aliases'));
+    return $self->_delobject($_[0], 'delalias', 1);
   }
 
 
   sub delmacro {
     my $self = shift;
-    return $self->_delobject($_[0], 'delmacro', 2, _('macro'), _('macros'));
+    return $self->_delobject($_[0], 'delmacro', 2);
   }
 
 
   sub deltimer {
     my $self = shift;
-    return $self->_delobject($_[0], 'deltimer', 3, _('timer'), _('timers'));
+    return $self->_delobject($_[0], 'deltimer', 3);
   }
 
 
   sub delhook {
     my $self  = shift;
-    return $self->_delobject($_[1], 'delhook', 4, _('hook'), _('hooks'), $_[0]);
+    return $self->_delobject($_[1], 'delhook', 4, $_[0]);
   }
 
 
@@ -474,7 +457,6 @@ sub _ { return gettext($_[0]); }
         $new_pos,
         $function,
         $objnum,
-        $objname,
         $extrafirstarg) = @_;
     my $ok;
 
@@ -486,7 +468,7 @@ sub _ { return gettext($_[0]); }
           eval("\$ok = \$self->_$function($old, $new_pos)");
         }
         if (!$ok) {
-          $self->echonl(sprintf(_('No such %s.'), $objname));
+          $self->echonl($self->_getnosuchmsg($objnum));
         }
       } else {
         my @found = $self->_getobjectnumber($old,
@@ -494,7 +476,7 @@ sub _ { return gettext($_[0]); }
                                             0,
                                             $extrafirstarg);
         if (scalar @found == 0) {
-          $self->echonl(sprintf(_('No such %s.'), $objname));
+          $self->echonl($self->_getnosuchmsg($objnum));
         } else {
           if ($extrafirstarg) {
             eval("\$ok += \$self->_$function(\$extrafirstarg, $found[0], $new_pos)");
@@ -503,7 +485,7 @@ sub _ { return gettext($_[0]); }
           }
 
           unless ($self->{SILENT}) {
-            $self->echonl(sprintf(_('Successfully moved %s.'), $objname));
+            $self->echonl(_('Successfully moved.'));
           }
         }
       }
@@ -515,32 +497,32 @@ sub _ { return gettext($_[0]); }
 
   sub movetrigger {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], 'movetrigger', 0, _('trigger'));
+    $self->_moveobject($_[0], $_[1], 'movetrigger', 0);
   }
 
 
   sub movealias {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], 'movealias', 1, _('alias'));
+    $self->_moveobject($_[0], $_[1], 'movealias', 1);
   }
 
 
   sub movemacro {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], 'movemacro', 2, _('macro'));
+    $self->_moveobject($_[0], $_[1], 'movemacro', 2);
   }
 
 
   sub movetimer {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], 'movetimer', 3, _('timer'));
+    $self->_moveobject($_[0], $_[1], 'movetimer', 3);
   }
 
 
   sub movehook {
     my $self  = shift;
     my $event = shift;
-    $self->_moveobject($_[0], $_[1], 'movehook', 4, _('hook'), $event);
+    $self->_moveobject($_[0], $_[1], 'movehook', 4, $event);
   }
 
 
@@ -564,7 +546,7 @@ sub _ { return gettext($_[0]); }
                                           0,
                                           $extrafirstarg);
       if (scalar @found == 0) {
-        $self->echonl(sprintf(_('No such %s'), _($function)));
+        $self->echonl($self->_getnosuchmsg($objnumber));
       } else {
         foreach (@found) {
           if ($extrafirstarg) {
@@ -871,6 +853,39 @@ sub _ { return gettext($_[0]); }
   }
 
 
+  sub _getdelmsg {
+    my $self = shift;
+    my ($deleted, $objnum) = @_;
+
+    my $msg;
+    if (!$deleted) {
+      return $self->_getnosuchmsg($objnum);
+    } else {
+      my $objname;
+      if ($objnum == 0) { $objname = ::ngettext('trigger', 'triggers', $deleted); }
+      if ($objnum == 1) { $objname = ::ngettext('alias',   'aliases',  $deleted); }
+      if ($objnum == 2) { $objname = ::ngettext('macro',   'macros',   $deleted); }
+      if ($objnum == 3) { $objname = ::ngettext('timer',   'timers',   $deleted); }
+      if ($objnum == 4) { $objname = ::ngettext('hook',    'hooks',    $deleted); }
+
+      return sprintf(::ngettext('One %1$s deleted',
+                                '%2$d %1$s deleted', $deleted),
+                     $objname, $deleted);
+    }
+  }
+
+  sub _getnosuchmsg {
+    my $self = shift;
+    my ($objnum) = @_;
+
+    if ($objnum == 0) { return _('No such trigger'); }
+    if ($objnum == 1) { return _('No such alias');   }
+    if ($objnum == 2) { return _('No such macro');   }
+    if ($objnum == 3) { return _('No such timer');   }
+    if ($objnum == 4) { return _('No such hook');    }
+  }
+
+
   sub writetolog {
     my $self = shift;
 
@@ -1272,9 +1287,10 @@ sub __sethelpfile {
 
 
 sub help {
-  if (!defined($_[0])) {
-    $_[0] = 'index';
-  }
+  my ($topic) = @_;
+
+  $topic ||= "index";
+  $topic =~ s/\$/\\\$/;
 
   open(HFILE, "<$__helpfile") or die(_('Cannot open help file.'));
 
@@ -1282,7 +1298,7 @@ sub help {
   while (<HFILE>) {
     chomp;
     if (!$outputting) {
-      next if ($_ ne "[$_[0]]");
+      next if ($_ !~ "\\[$topic\\]");
       $outputting = 1;
     } else {
       if ($_ =~ /^\[/) {
@@ -1290,10 +1306,15 @@ sub help {
         return;
       }
 
-      $::world->echonl($_);
+      if ($_ =~ /^[&^]/) {
+        $::world->echonl(::colorize($_));
+      } else {
+        $::world->echonl($_);
+      }
     }
   }
 
+  close(HFILE);
   $::world->echonl(_('Help topic not found.'));
 }
 
@@ -1387,23 +1408,3 @@ sub _preparemsdpdata {
   my $msdp = MSDP->new();
   return $msdp->encode($data->{'data'});
 }
-
-
-### Deprecated functions
-sub getwindowsize {
-  $::world->echonl(_('Warning: the getwindowsize() function is deprecated and will be removed.'));
-  $::world->echonl(_('Use $window->getsize() instead.'));
-  $::window->getsize();
-}
-
-sub minimize {
-  $::world->echonl(_('Warning: the minimize() function is deprecated and will be removed.'));
-  $::world->echonl(_('Use $window->minimize() instead.'));
-  $::window->minimize();
-}
-
-sub path {
-  $::world->echonl(_('Warning: the path() function is deprecated and will be removed.'));
-  $::world->echonl(_('Use $world->path() instead.'));
-  $::world->path($_[0]);
-}
