@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,6 +103,24 @@ ansitextview_append_stringf(WorldGUI    *gui,
 }
 
 
+void
+ansitextview_append_stringf_nl(WorldGUI    *gui,
+                               const gchar *format,
+                               ...)
+{
+  /*
+   * Formats a string using printf syntax and outputs it.
+   */
+  va_list  ap;
+  gchar   *str;
+
+  va_start(ap, format);
+  str = g_strdup_vprintf(format, ap);
+  ansitextview_append_string_internal(gui, str, TRUE);
+  g_free(str);
+}
+
+
 void
 ansitextview_append_string_with_fgcolor(WorldGUI    *gui,
                                         const gchar *str,
@@ -265,19 +283,8 @@ ansitextview_update_color_tags(WorldGUI *gui, World *world)
                           : PANGO_WEIGHT_NORMAL),
                NULL);
 
-  /* Update default colors in the TextView */
-  gtk_widget_override_background_color(GTK_WIDGET(gui->txtView),
-                                       GTK_STATE_FLAG_NORMAL,
-                                       world->defback);
-  gtk_widget_override_background_color(GTK_WIDGET(gui->txtViewScroll),
-                                       GTK_STATE_FLAG_NORMAL,
-                                       world->defback);
-  gtk_widget_override_color(GTK_WIDGET(gui->txtViewScroll),
-                            GTK_STATE_FLAG_NORMAL,
-                            world->deffore);
-  gtk_widget_override_color(GTK_WIDGET(gui->txtView),
-                            GTK_STATE_FLAG_NORMAL,
-                            world->deffore);
+  /* Update colors */
+  configure_css(gui, world);
 }
 
 
@@ -419,12 +426,8 @@ ansitextview_op_text_added(WorldGUI *gui, MainThreadOperation *operation)
   lines = gtk_text_buffer_get_line_count(gui->txtBuffer);
   if (gui->lblLines) {
     gint totallines = gui->world->deleted_lines + lines;
-    if (totallines == 1) {
-      gtk_label_set_text(gui->lblLines, _("1 line"));
-    } else {
-      sprintf(msg, _("%d lines"), totallines);
-      gtk_label_set_text(gui->lblLines, msg);
-    }
+    sprintf(msg, ngettext("%d line", "%d lines", totallines), totallines);
+    gtk_label_set_text(gui->lblLines, msg);
   }
 
   /* Add time that these lines were processed */
