@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -185,7 +185,7 @@ GtkWidget *
 create_cmd_history_dialog(GtkWindow *parent, World *world)
 {
   gchar            *objects[] = { "dlgCmdHistory",
-                                  "adjustment1", "adjustment2",
+                                  "adjSpnCHDelay", "adjSpnNCommands",
                                   NULL };
   GError           *error = NULL;
   GObject          *dlg;
@@ -212,6 +212,7 @@ create_cmd_history_dialog(GtkWindow *parent, World *world)
                     there is need to abort the program because of this. */
   }
   dlg = gtk_builder_get_object(world->ui_builder, "dlgCmdHistory");
+  gtk_window_set_transient_for(GTK_WINDOW(dlg), GTK_WINDOW(wndMain));
 
   /* Configure tree view */
   viewCommands = GTK_TREE_VIEW(gtk_builder_get_object(world->ui_builder,
@@ -268,28 +269,12 @@ cmdhistory_recall_cb(GtkWidget *widget, gpointer data)
 
   n_selected = gtk_tree_selection_count_selected_rows(selection);
   if (n_selected == 0) {
-    GtkWidget *msgdlg;
-
-    msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgCmdHistory),
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_ERROR,
-                                    GTK_BUTTONS_OK,
-                                    _("No command selected."));
-    gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Warning"));
-    gtk_dialog_run(GTK_DIALOG(msgdlg));
-    gtk_widget_destroy(msgdlg);
+    kc_error_dialog(GTK_WINDOW(world->dlgCmdHistory),
+                    _("No command selected."));
     return;
   } else if (n_selected > 1) {
-    GtkWidget *msgdlg;
-
-    msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgCmdHistory),
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_ERROR,
-                                    GTK_BUTTONS_OK,
-                                    _("More than one command selected."));
-    gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Warning"));
-    gtk_dialog_run(GTK_DIALOG(msgdlg));
-    gtk_widget_destroy(msgdlg);
+    kc_error_dialog(GTK_WINDOW(world->dlgCmdHistory),
+                    _("More than one command selected."));
     return;
   }
 
@@ -458,6 +443,8 @@ cmdhistory_find_cb(GtkWidget *widget, gpointer data)
 
       world->dlgCmdHistoryFind
         = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "dlgFind"));
+      gtk_window_set_transient_for(GTK_WINDOW(world->dlgCmdHistoryFind),
+                                   GTK_WINDOW(world->dlgCmdHistory));
     }
 
     txtSearchText = GTK_ENTRY(gtk_builder_get_object(world->ui_builder,
@@ -468,22 +455,15 @@ cmdhistory_find_cb(GtkWidget *widget, gpointer data)
     gtk_dialog_set_default_response(GTK_DIALOG(world->dlgCmdHistoryFind),
                                     GTK_RESPONSE_OK);
 
+    gtk_widget_show_all(world->dlgCmdHistoryFind);
     while (1) {
       if (gtk_dialog_run(GTK_DIALOG(world->dlgCmdHistoryFind)) == GTK_RESPONSE_OK) {
         const gchar *search_text;
 
         search_text = gtk_entry_get_text(txtSearchText);
         if (strcmp(search_text, "") == 0) {
-          GtkWidget *msgdlg;
-
-          msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgCmdHistory),
-                                          GTK_DIALOG_MODAL,
-                                          GTK_MESSAGE_ERROR,
-                                          GTK_BUTTONS_OK,
-                                          _("Enter some text to search for."));
-          gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Warning"));
-          gtk_dialog_run(GTK_DIALOG(msgdlg));
-          gtk_widget_destroy(msgdlg);
+          kc_error_dialog(GTK_WINDOW(world->dlgCmdHistory),
+                          _("Enter some text to search for."));
           continue;
         }
 
@@ -507,16 +487,8 @@ cmdhistory_find_cb(GtkWidget *widget, gpointer data)
     }
   } else {   /* Verify if there was a search */
     if (!world->cmdfind_string) {
-      GtkWidget *msgdlg;
-
-      msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgCmdHistory),
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_ERROR,
-                                      GTK_BUTTONS_OK,
-                                      _("Use the Find button to find the first result."));
-      gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Warning"));
-      gtk_dialog_run(GTK_DIALOG(msgdlg));
-      gtk_widget_destroy(msgdlg);
+      kc_error_dialog(GTK_WINDOW(world->dlgCmdHistory),
+                      _("Use the Find button to find the first result."));
       return;
     }
 
@@ -564,16 +536,8 @@ cmdhistory_find_cb(GtkWidget *widget, gpointer data)
     }
 
     if (error && !found) {
-      GtkWidget *msgdlg;
-
-      msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgCmdHistory),
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_WARNING,
-                                      GTK_BUTTONS_OK,
-                                      _("Command not found."));
-      gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Warning"));
-      gtk_dialog_run(GTK_DIALOG(msgdlg));
-      gtk_widget_destroy(msgdlg);
+      kc_error_dialog(GTK_WINDOW(world->dlgCmdHistory),
+                      _("Command not found."));
       break;
     }
   }
