@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,7 @@
 
 #include <zlib.h>
 
-#ifdef HAVE_LIBGNUTLS
-#  include <gnutls/gnutls.h>
-#endif
+#include <gnutls/gnutls.h>
 
 
 /**********************
@@ -283,6 +281,9 @@ typedef struct AnsiParseState_s AnsiParseState;
 struct WorldGUI_s
 {
   struct world_s    *world;
+
+  GtkCssProvider    *css_provider;
+
   GtkWidget         *vbox;
   GtkPaned          *split_pane;
   gint               last_split_position;
@@ -378,6 +379,10 @@ struct world_s
   char             *name_display_pattern;
   gboolean          use_tooltips;
 
+  /* Scrolling settings */
+  gboolean         scrollOutput;
+  glong            buffer_lines;
+
   /* Scripting support */
   gchar           *scriptfile;
   GSList          *triggers;
@@ -401,10 +406,6 @@ struct world_s
 
   HookList         hooks;
 
-  /* Scrolling settings */
-  gboolean         scrollOutput;
-  glong            buffer_lines;
-
   /* Input settings */
   gboolean         repeat_commands;
   gboolean         cmd_echo;
@@ -455,11 +456,7 @@ struct world_s
   gboolean         connected_at_least_once;
   gchar           *errmsg;        /* Error message to display */
   GIOChannel      *iochan;
-#ifndef __MINGW32__
   int              sock;
-#else
-  SOCKET           sock;
-#endif
   guint            io_watch_id;
   guint            timeout_id;
   glong            deleted_lines;
@@ -563,11 +560,9 @@ struct world_s
   PerlInterpreter *perl_interpreter;
 
   /* TLS/SSL support */
-  gboolean       use_tls;
-#ifdef HAVE_LIBGNUTLS
+  gboolean         use_tls;
   gnutls_session_t tls_session;
   int              tls_handshake_dir;
-#endif
 
   /* Inter-thread communication */
   GRecMutex    perl_mutex;
@@ -938,10 +933,8 @@ extern GdkRGBA     defbold;              /* Default bold foreground color */
 extern GdkRGBA     defback;              /* Default background color */
 extern GdkRGBA     defboldback;          /* Default bold background color */
 extern GdkRGBA     defansi[];            /* Default ansi colors */
-#ifdef HAVE_LIBGNUTLS
 /* gnutls certificate credentials */
 extern gnutls_certificate_credentials_t tls_certif_cred;
-#endif
 
 
 /*********************************
@@ -983,6 +976,7 @@ void      world_gui_size_textview(WorldGUI *gui);
 void      worldgui_determine_supported_chars(WorldGUI *gui);
 void      free_world_gui(WorldGUI *gui);
 void      configure_gui(WorldGUI *gui, World *world);
+void      configure_css(WorldGUI *gui, World *world);
 void      worldgui_configure_spell(WorldGUI *gui);
 void      clear_button_cb(GtkButton *button, gpointer data);
 void      send_naws_size(World *world);
@@ -1046,6 +1040,9 @@ void      ansitextview_append_string_nl(WorldGUI    *gui,
 void      ansitextview_append_stringf(WorldGUI    *gui,
                                       const gchar *format,
                                       ...);
+void      ansitextview_append_stringf_nl(WorldGUI    *gui,
+                                         const gchar *format,
+                                         ...);
 void      ansitextview_append_string_with_fgcolor(WorldGUI    *gui,
                                                   const gchar *str,
                                                   gint         fg_color);
@@ -1078,6 +1075,7 @@ void      ansitextview_op_apply_highlight(WorldGUI            *gui,
  * Function prototypes - Worlds *
  ********************************/
 void      set_default_colors(World *world);
+void      create_default_world(void);
 World    *create_new_world(gboolean load_defaults);
 void      init_threads(World *world);
 void      free_world(World *world);
@@ -1116,6 +1114,8 @@ void       fill_we_general_tab(World *world, GtkBuilder *ui_builder);
 void       update_we_general_parameters(World *world, GtkBuilder *ui_builder);
 GObject   *get_we_mainwindow_tab(GtkBuilder *ui_builder);
 void       fill_we_mainwindow_tab(World *world, GtkBuilder *ui_builder);
+void       update_we_mainwindow_parameters(World      *world,
+                                           GtkBuilder *ui_builder);
 GObject   *get_we_colors_tab(World *world, GtkBuilder *ui_builder);
 GObject   *get_we_statusbar_tab(GtkBuilder *ui_builder);
 void       fill_we_statusbar_tab(World *world, GtkBuilder *ui_builder);
@@ -1142,9 +1142,6 @@ GObject   *get_we_vars_tab(World *world);
 GObject   *get_we_protocols_tab(GtkBuilder *ui_builder);
 void       fill_we_protocols_tab(World *world, GtkBuilder *ui_builder);
 void       update_we_protocols_parameters(World *world, GtkBuilder *ui_builder);
-GObject   *get_we_misc_tab(GtkBuilder *ui_builder);
-void       fill_we_misc_tab(World *world, GtkBuilder *ui_builder);
-void       update_we_misc_parameters(World *world, GtkBuilder *ui_builder);
 GObject   *get_we_advanced_tab(World *world, GtkBuilder *ui_builder);
 void       fill_we_advanced_tab(World *world, GtkBuilder *ui_builder);
 void       update_we_advanced_parameters(World *world, gboolean *newworld,
@@ -1172,9 +1169,8 @@ void       we_guied_selection_changed_cb(GtkTreeSelection *selection,
                                          gpointer          data);
 
 GtkWidget *we_guied_confirm_delete_dialog_new(GtkWindow   *parent,
-                                              int          n,
-                                              const gchar *singular,
-                                              const gchar *plural);
+                                              const gchar *objname,
+                                              int          n);
 void       we_lplugin_insert_plugin(World *world, Plugin *plugin);
 void       we_lplugin_update_plugin(World *world, Plugin *plugin);
 
@@ -1328,7 +1324,7 @@ void     free_permanent_variable(gchar *variable, gpointer data);
  * Function Prototypes - Hooks *
  *******************************/
 gboolean      connect_hook(World       *world,
-                           const gchar *hookname,
+                           const gchar *event,
                            int          pos,
                            gchar       *action,
                            gchar       *name,
@@ -1339,24 +1335,27 @@ void          execute_hook(World       *world,
 void          execute_hook_immediately(World       *world,
                                        const gchar *hook,
                                        const gchar *hookdata);
-void          list_hooks(World *world, const gchar *hookname, Plugin *plugin);
-void          list_hook(World *world, const gchar *hookname, int pos);
-gboolean      delete_hook(World *world,
-                          const gchar *hookname,
-                          int pos,
-                          GSList *hook);
-gboolean      move_hook(World *world, const gchar *hookname,
+void          list_hooks(World *world, const gchar *event, Plugin *plugin);
+void          list_hook(World *world, const gchar *event, int pos);
+gboolean      delete_hook(World       *world,
+                          const gchar *event,
+                          int          pos,
+                          GSList      *hook);
+gboolean      move_hook(World *world, const gchar *event,
                         gint old_pos, gint new_pos);
 void          free_hook(Hook *hook, gpointer data);
 void          save_hooks(GString *str, World *world);
 void          save_hook(GString *str, Hook *hook);
 GSList      **get_hook_list_for_writing(World        *world,
-                                        const gchar  *hookname,
+                                        const gchar  *event,
                                         gint        **poscounter);
-GSList       *get_hook_list_for_reading(World       *world,
-                                        const gchar *hookname,
-                                        gint        *pos);
-GtkTreeModel *get_hook_model(World *world, const gchar *hookname);
+gboolean      get_hook_list_for_reading(World        *world,
+                                        const gchar  *event,
+                                        GSList      **list,
+                                        gint         *pos);
+GSList       *get_hook_list_or_warn_if_nonexistent(World       *world,
+                                                   const gchar *event);
+GtkTreeModel *get_hook_model(World *world, const gchar *event);
 gboolean      are_there_enabled_server_data_hooks(World *world);
 void          mainthread_op_execute_on_received_text_hook(HookExecution *hook_execution);
 
@@ -1365,6 +1364,7 @@ void          mainthread_op_execute_on_received_text_hook(HookExecution *hook_ex
  * Function Prototypes - Logging *
  *********************************/
 void     write_log_line(World *world, const gchar *line, time_t *line_time);
+void     start_log_and_display_result(World *world);
 gboolean start_log(World *world, gint lines, gchar **errormsg);
 void     stop_log(World *world);
 
@@ -1386,4 +1386,17 @@ void     make_startup_plugin_list_for_editing(World *world);
 void play_sound(const gchar *file);
 
 
+/*********************************************************
+ * Function prototypes - Miscellaneous utility functions *
+ *********************************************************/
+void   add_css_provider_and_class(GtkWidget      *widget,
+                                  GtkCssProvider *provider,
+                                  const gchar    *class);
+gchar *pango_font_to_css(const gchar *pango_font);
+void   kc_error_dialog(GtkWindow *parent, const gchar *format, ...);
+void   kc_error_dialog_with_title(GtkWindow   *parent,
+                                  const gchar *title,
+                                  const gchar *format, ...);
+
+
 #endif
