@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -94,6 +94,22 @@ write_log_line(World *world, const char *line, time_t *line_time)
 }
 
 
+void
+start_log_and_display_result(World *world)
+{
+  gchar *errmsg = NULL;
+
+  if (start_log(world, 0, &errmsg)) {
+    ansitextview_append_stringf_nl(world->gui,
+                                   _("Logging to file %s."),
+                                   world->log_actual_file);
+  } else {
+    ansitextview_append_string_nl(world->gui, errmsg);
+    g_free(errmsg);
+  }
+}
+
+
 gboolean
 start_log(World *world, gint lines, gchar **errmsg)
 {
