@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,19 +25,10 @@
 #include "libintl-wrapper.h"
 #include <locale.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_LIBGNUTLS
-#  include <gnutls/gnutls.h>
-#endif
+#include <gnutls/gnutls.h>
 
 #ifdef __MINGW32__
 #  include <winsock2.h>
-#endif
-
-#if defined __CYGWIN32__
-#  include <sys/cygwin.h>
-#  include <windows.h>
-#  include <shlobj.h>
-#elif defined __WIN32__
 #  include <windows.h>
 #  include <shlobj.h>
 #endif
@@ -57,9 +48,7 @@ FILE *rdumpFile = NULL;
 /*************************
  * File global variables *
  *************************/
-#ifdef HAVE_LIBGNUTLS
 gnutls_certificate_credentials_t tls_certif_cred;
-#endif
 
 
 /************************
@@ -100,15 +89,7 @@ main(int argc, char *argv[], char *env[])
 
 
   /* Internationalization initialization */
-#if defined __CYGWIN32__
-  /* cygwin bindtextdomain requires a POSIX path */
-  char posixpath[MAX_PATH];
-
-  cygwin_conv_to_posix_path(get_kildclient_installed_file("locale"),
-                            posixpath);
-  bindtextdomain(GETTEXT_PACKAGE, posixpath);
-#elif defined __WIN32__
-  /* Other windows, specifically MINGW32 */
+#ifdef __MINGW32__
   bindtextdomain(GETTEXT_PACKAGE, get_kildclient_installed_file("locale"));
 #else
   bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
@@ -153,11 +134,9 @@ main(int argc, char *argv[], char *env[])
 #endif
 
   gtk_init(&argc, &argv);
-  gtk_settings_set_long_property(gtk_settings_get_default(),
-                                 "gtk-entry-select-on-focus", 0,
-                                 "KildClient");
 
   read_global_preferences(&x, &y, &width, &height);
+  create_default_world();
 
   gui = world_gui_new(TRUE);
   wndMain = create_main_window(gui);
@@ -165,12 +144,10 @@ main(int argc, char *argv[], char *env[])
 
   init_perl_system();
 
-#ifdef HAVE_LIBGNUTLS
   gnutls_global_init();
   gnutls_certificate_allocate_credentials(&tls_certif_cred);
   /* We don't really verify certificates */
   /*gnutls_certificate_set_x509_trust_file(tls_certif_cred, CAFILE, GNUTLS_X509_FMT_PEM);*/
-#endif
 
   gtk_widget_show_all(wndMain);
 
@@ -219,10 +196,8 @@ main(int argc, char *argv[], char *env[])
 
   PERL_SYS_TERM();
 
-#ifdef HAVE_LIBGNUTLS
   gnutls_certificate_free_credentials(tls_certif_cred);
   gnutls_global_deinit();
-#endif
 
   if (dumpFile) {
     fclose(dumpFile);
@@ -258,21 +233,15 @@ confirm_quit(void)
     return TRUE;
   }
 
-  if (n_open == 1) {
-    msgdlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_QUESTION,
-                                    GTK_BUTTONS_NONE,
-                                    _("There is one open world. Do you really want to quit?"));
-  } else {
-    msgdlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_QUESTION,
-                                    GTK_BUTTONS_NONE,
-                                    _("There are %d open worlds. Do you really want to quit?"),
-                                    n_open);
-  }
-  gtk_window_set_title(GTK_WINDOW(msgdlg), _("Really Quit KildClient?"));
+  msgdlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
+                                  GTK_DIALOG_MODAL,
+                                  GTK_MESSAGE_QUESTION,
+                                  GTK_BUTTONS_NONE,
+                                  ngettext("There is one open world. Do you really want to quit?",
+                                           "There are %d open worlds. Do you really want to quit?",
+                                           n_open),
+                                  n_open);
+  gtk_window_set_title(GTK_WINDOW(msgdlg), _("Really quit KildClient?"));
   gtk_dialog_add_buttons(GTK_DIALOG(msgdlg),
                          _("_Don't quit"), GTK_RESPONSE_NO,
                          _("_Quit"), GTK_RESPONSE_YES,
@@ -289,7 +258,7 @@ confirm_quit(void)
  * Functions to get the user path (e.g. ~/.kildclient) and the
  * directory where the data files are installed.
  */
-#ifndef __WIN32__
+#ifndef __MINGW32__
 #include <unistd.h>
 
 const char *
@@ -317,7 +286,7 @@ get_kildclient_installed_file(const char *file)
 
   return path;
 }
-#else /* __WIN32__ */
+#else /* __MINGW32__ */
 const char *
 get_kildclient_directory_path(void)
 {
