@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,17 +35,13 @@
 #else
 #  include <winsock2.h>
 #endif
-#ifdef HAVE_LIBGNUTLS
-#  include <gnutls/gnutls.h>
-#  include <gnutls/x509.h>
-#  include <gnutls/openpgp.h>
-#endif
+#include <gnutls/gnutls.h>
+#include <gnutls/x509.h>
+#include <gnutls/openpgp.h>
 
 #include "kildclient.h"
 #include "perlscript.h"
 
-#include "ansi.h"
-
 
 /******************
  * Initialization *
@@ -170,13 +166,13 @@ create_main_window(WorldGUI *gui)
   gtk_builder_connect_signals(main_builder, NULL);
 
   window = GTK_WIDGET(gtk_builder_get_object(main_builder, "wndMain"));
-#ifndef __WIN32__
-  gtk_window_set_icon_from_file(GTK_WINDOW(window),
-                                SYSDATADIR "/pixmaps/kildclient.png",
-                                NULL);
+#ifndef __MINGW32__
   gtk_window_set_default_icon_from_file(SYSDATADIR "/pixmaps/kildclient.png",
                                         NULL);
-#endif
+#else /* defined __MINGW32__ */
+  gtk_window_set_default_icon_from_file(get_kildclient_installed_file("kildclient.png"),
+                                        NULL);
+#endif /* __MINGW32__ */
 
   /* User interface */
   ntbkWorlds = GTK_WIDGET(gtk_builder_get_object(main_builder, "ntbkWorlds"));
@@ -228,6 +224,7 @@ set_main_window_size(int x, int y, int width, int height, WorldGUI *gui)
 }
 
 
+static
 void
 restore_main_window_size(int x, int y, int width, int height, WorldGUI *gui)
 {
@@ -236,21 +233,55 @@ restore_main_window_size(int x, int y, int width, int height, WorldGUI *gui)
 }
 
 
+static
 void
 set_initial_window_size(WorldGUI *gui)
 {
-  /* Since world_gui_size_textview() sets the minimum size, and we
-     only want to set the initial size, which is only possible for
-     windows, we use a little trick. */
-  GtkRequisition requisition;
+  PangoLayout          *layout;
+  PangoFontDescription *font;
+  PangoRectangle        logical_rect;
+  gint                  char_width, char_height;
+  gint                  tv_width, tv_height;
+  GtkRequisition        window_size;
 
-  world_gui_size_textview(gui);
-  gtk_widget_get_preferred_size(GTK_WIDGET(gui->txtView), &requisition, NULL);
-  gtk_widget_set_size_request(GTK_WIDGET(gui->txtView),
-                              100, 100);
-  gtk_window_resize(GTK_WINDOW(wndMain),
-                    requisition.width,
-                    requisition.height * 1.5);
+  /* At this moment, calling ansitextview_get_char_size() results in an
+     invalid value, probably because the GtkTextView is not yet display
+     on screen. So we set the default font manually. */
+  layout = gtk_widget_create_pango_layout(GTK_WIDGET(gui->txtView), "W");
+  font = pango_font_description_from_string(DEFAULT_TERMINAL_FONT);
+  pango_layout_set_font_description(layout, font);
+  pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
+  pango_font_description_free(font);
+  g_object_unref(layout);
+  char_width  = logical_rect.width;
+  char_height = logical_rect.height;
+#ifndef __MINGW32__
+  /* On Linux, I observed the result to be 1 pixel larger than the
+     actual size, but this didn't happen under Window. */
+  char_width  -= 1;
+  char_height -= 1;
+#endif
+
+  /* Set a minimum size of 80x24 for the main MUD area */
+  tv_width  = 80 * char_width  + 1;
+  tv_height = 24 * char_height + 1;
+  gtk_scrolled_window_set_min_content_width(gui->scrolled_win, tv_width);
+  gtk_scrolled_window_set_min_content_height(gui->scrolled_win, tv_height);
+
+  /* Find out what size the window would be with a MUD area that size */
+  gtk_widget_get_preferred_size(wndMain, &window_size, NULL);
+
+  /* Remove the constraint on the MUD area size, so that the user can
+     shrink it if he wishes */
+  gtk_scrolled_window_set_min_content_width(gui->scrolled_win, tv_width / 3);
+  gtk_scrolled_window_set_min_content_height(gui->scrolled_win, tv_height / 3);
+
+  /* But make the window start at the size it would have for a 80x24 area,
+     with a little extra width (without it the size would be a couple
+     pixels smaller than necessary_. */
+  gtk_window_set_default_size(GTK_WINDOW(wndMain),
+                              window_size.width + char_width,
+                              window_size.height);
 }
 
 
@@ -581,6 +612,7 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
 
   dlgStatistics  = GTK_WIDGET(gtk_builder_get_object(ui_builder,
                                                     "dlgStatistics"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgStatistics), GTK_WINDOW(wndMain));
   lblName        = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblName"));
   lblHost        = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblHost"));
   lblPort        = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblPort"));
@@ -665,7 +697,6 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
   g_free(str);
 
   /* TLS information */
-#ifdef HAVE_LIBGNUTLS
   if (currentWorld->use_tls) {
     GtkLabel                  *lblTLS;
     GtkLabel                  *lblTLSCipher;
@@ -797,9 +828,9 @@ menu_statistics_cb(GtkMenuItem *widget, gpointer data)
     lblTLS = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblTLS"));
     gtk_label_set_text(lblTLS, _("None"));
   }
-#endif
 
   /* Run the dialog */
+  gtk_widget_show_all(dlgStatistics);
   gtk_dialog_run(GTK_DIALOG(dlgStatistics));
   gtk_widget_destroy(dlgStatistics);
   g_object_unref(ui_builder);
@@ -820,10 +851,10 @@ menu_manual_cb(GtkMenuItem *widget, gpointer data)
 {
   gchar *manualurl;
 
-#ifndef __WIN32__
-  manualurl = g_strdup_printf("file://%s", MANUALDIR "/index.html");
+#ifndef __MINGW32__
+  manualurl = g_strdup_printf("file://%s", MANUALDIR "/index.xhtml");
 #else
-  manualurl = g_strdup_printf(get_kildclient_installed_file("manual\\html\\index.html"));
+  manualurl = g_strdup_printf(get_kildclient_installed_file("manual\\html\\index.xhtml"));
 #endif
   menu_url_open(NULL, manualurl);
 }
@@ -846,6 +877,7 @@ menu_about_cb(GtkMenuItem *widget, gpointer data)
     }
     dlgAbout = GTK_ABOUT_DIALOG(gtk_builder_get_object(main_builder,
                                                        "dlgAbout"));
+    gtk_window_set_transient_for(GTK_WINDOW(dlgAbout), GTK_WINDOW(wndMain));
     gtk_about_dialog_set_version(dlgAbout, VERSION);
     /* TODO: Will not be necessary if future glade versions do not insist
        on setting this property. */
