@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,7 +77,6 @@ create_multi_line_send_dialog(GtkWindow *parent, World *world)
   GtkSpinButton *spnDelay;
   GtkSpinButton *spnLinesATime;
 
-  PangoFontDescription *fontDesc;
   PangoLayout          *layout;
   gint                  char_width;
   PangoRectangle        logical_rect;
@@ -96,24 +95,21 @@ create_multi_line_send_dialog(GtkWindow *parent, World *world)
                     there is need to abort the program because of this. */
   }
   dlg = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "dlgMLSend"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlg), GTK_WINDOW(wndMain));
 
-  /* Set the fonts */
-  fontDesc = pango_font_description_from_string(world->entryfont);
-
+  /* Configure widgets to use input font */
   txtInitial = GTK_WIDGET(gtk_builder_get_object(world->ui_builder,
                                                  "txtInitial"));
-  gtk_widget_override_font(txtInitial, fontDesc);
+  add_css_provider_and_class(txtInitial, world->gui->css_provider, "input");
 
   text = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "txtFinal"));
-  gtk_widget_override_font(text, fontDesc);
+  add_css_provider_and_class(text, world->gui->css_provider, "input");
 
-  text  = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "txtStart"));
-  gtk_widget_override_font(text, fontDesc);
+  text = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "txtStart"));
+  add_css_provider_and_class(text, world->gui->css_provider, "input");
 
-  text    = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "txtEnd"));
-  gtk_widget_override_font(text, fontDesc);
-
-  pango_font_description_free(fontDesc);
+  text = GTK_WIDGET(gtk_builder_get_object(world->ui_builder, "txtEnd"));
+  add_css_provider_and_class(text, world->gui->css_provider, "input");
 
   /* Default values */
   spnDelay = GTK_SPIN_BUTTON(gtk_builder_get_object(world->ui_builder,
