@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #  include <sys/socket.h>
 #  include <netdb.h>
 #  include <arpa/inet.h>
-#else /* defined __MINGW32__ */
+#else /* ! defined __MINGW32__ */
 #  include <winsock2.h>
 #  include <ws2tcpip.h>
 #endif
@@ -45,7 +45,6 @@
 #include "kildclient.h"
 #include "perlscript.h"
 #include "net.h"
-#include "ansi.h"
 
 
 /*************************
@@ -66,12 +65,10 @@ static gboolean connect_ready_cb(GIOChannel   *iochan,
                                  GIOCondition  cond,
                                  gpointer      data);
 static gboolean connected_to_dispatcher(World *world);
-#ifdef HAVE_LIBGNUTLS
 static gboolean tls_handshake_cb(GIOChannel   *iochan,
                                  GIOCondition  cond,
                                  gpointer      data);
 static gboolean tls_handshake_timeout_cb(gpointer data);
-#endif
 static void     disconnected_decide_action(World *world, gint action);
 static gboolean data_ready_cb(GIOChannel   *iochan,
                               GIOCondition  cond,
@@ -97,38 +94,12 @@ connect_to(World *world, gchar **errmsg)
   struct resolve_data_s *resolve_data;
   GThread *resolver_thread;
 
-#ifndef HAVE_LIBGNUTLS
-  /* Oops, we cannot do that */
-  if (world->use_tls) {
-    GtkDialog *msgdlg = msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                        GTK_DIALOG_MODAL,
-                                                        GTK_MESSAGE_QUESTION,
-                                                        GTK_BUTTONS_NONE,
-                                                        _("You're attempting to connect to a world that uses SSL, but this version of KildClient has been built without SSL support. Try to connect without SSL?"));
-    gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Question"));
-    gtk_dialog_add_buttons(msgdlg,
-                           _("Connect without SSL"), GTK_RESPONSE_YES,
-                           _("Do not connect"), GTK_RESPONSE_NO,
-                           NULL);
-    gtk_dialog_set_default_response(msgdlg, GTK_RESPONSE_NO);
-
-    if (gtk_dialog_run(msgdlg) == GTK_RESPONSE_YES) {
-      world->use_tls = FALSE;
-      gtk_widget_destroy(GTK_WIDGET(msgdlg));
-    } else {
-      *errmsg = g_strdup(_("This version of KildClient does not have SSL support."));
-      gtk_widget_destroy(msgdlg);
-      return FALSE;
-    }
-  }
-#else /* defined HAVE_LIBGNUTLS */
   if (world->use_tls) {
     gnutls_init(&world->tls_session, GNUTLS_CLIENT);
     gnutls_priority_set_direct(world->tls_session, "NORMAL", NULL);
     gnutls_credentials_set(world->tls_session,
                            GNUTLS_CRD_CERTIFICATE, tls_certif_cred);
   }
-#endif
 
   /* Set up gui */
   if (!world->connected_at_least_once) {
@@ -368,7 +339,7 @@ continue_connecting_cb(gpointer data)
 
     error = WSAGetLastError();
     if (error != WSAEWOULDBLOCK) {
-      world->errmsg = g_strdup_printf(_("Could not connect to host %s port %s: Error #%d"),
+      world->errmsg = g_strdup_printf(_("Could not connect to host %s port %s: error #%d"),
                                       world->host, world->port,
                                       error);
       return FALSE;
@@ -469,10 +440,10 @@ connect_ready_cb(GIOChannel   *iochan,
   }
   if (sockerror) {
     if (world->proxy_used.type == PROXY_NONE) {
-      world->errmsg = g_strdup_printf(_("Unable to connect to host %s: Error #%d."),
+      world->errmsg = g_strdup_printf(_("Unable to connect to host %s: error #%d."),
                                       world->host, sockerror);
     } else {
-      world->errmsg = g_strdup_printf(_("Unable to connect to proxy host %s: Error #%d."),
+      world->errmsg = g_strdup_printf(_("Unable to connect to proxy host %s: error #%d."),
                                       world->proxy_used.server, sockerror);
     }
     disconnect_world(world, FALSE);
@@ -487,10 +458,10 @@ connect_ready_cb(GIOChannel   *iochan,
      to be safe. */
   g_warning("Unreachable code in connect_read_cb.");
   if (world->proxy_used.type == PROXY_NONE) {
-    world->errmsg = g_strdup_printf(_("Unable to connect to host %s: Error #%d."),
+    world->errmsg = g_strdup_printf(_("Unable to connect to host %s: error #%d."),
                                     world->host, sockerror);
   } else {
-    world->errmsg = g_strdup_printf(_("Unable to connect to proxy host %s: Error #%d."),
+    world->errmsg = g_strdup_printf(_("Unable to connect to proxy host %s: error #%d."),
                                     world->proxy_used.server, sockerror);
   }
   disconnect_world(world, FALSE);
@@ -519,7 +490,6 @@ connected_to_dispatcher(World *world)
 }
 
 
-#ifdef HAVE_LIBGNUTLS
 gboolean
 perform_tls_handshake(World *world)
 {
@@ -533,13 +503,7 @@ perform_tls_handshake(World *world)
     gtk_label_set_text(world->gui->lblStatus, status_text);
     g_free(status_text);
 
-#ifndef __x86_64      /* This is to remove a warning about pointer sizes */
-    gnutls_transport_set_ptr(world->tls_session,
-                             (gnutls_transport_ptr_t) world->sock);
-#else
-    gnutls_transport_set_ptr(world->tls_session,
-                             (gnutls_transport_ptr_t) (long) world->sock);
-#endif
+    gnutls_transport_set_int(world->tls_session, world->sock);
     /* Register callback to perform the TLS handshake
      * The first action is we sending data (ClientHello) */
     world->tls_handshake_dir = 1;
@@ -575,8 +539,7 @@ tls_handshake_cb(GIOChannel   *iochan,
 
   if (gnutls_error_is_fatal(ret) != 0) {
     /* Fatal error */
-    gnutls_deinit(world->tls_session);
-    world->errmsg = g_strdup_printf(_("SSL Handshake failed: %s"),
+    world->errmsg = g_strdup_printf(_("SSL handshake failed: %s"),
                                     gnutls_strerror(ret));
     disconnect_world(world, FALSE);
     /* Do not call the function again */
@@ -617,21 +580,13 @@ tls_handshake_timeout_cb(gpointer data)
 
   // The world might have been closed
   if (g_list_index(open_worlds, world) != -1 && world->connecting) {
-    gnutls_deinit(world->tls_session);
-    world->errmsg = g_strdup_printf(_("SSL Handshake took too long."));
+    world->errmsg = g_strdup_printf(_("SSL handshake took too long."));
     disconnect_world(world, FALSE);
   }
 
   /* Never called again */
   return FALSE;
 }
-#else
-gboolean
-perform_tls_handshake(World *world)
-{
-  return connected_to(world);
-}
-#endif
 
 
 gboolean
@@ -670,17 +625,8 @@ connected_to(World *world)
   perform_auto_logon(world);
   execute_hook(world, "OnConnect", NULL);
   if (world->log_autostart) {
-    gchar *errmsg = NULL;
-
     stop_log(world);
-    if (start_log(world, 0, &errmsg)) {
-      ansitextview_append_stringf(world->gui,
-                                  _("Logging to file %s.\n"),
-                                  world->log_actual_file);
-    } else {
-      ansitextview_append_string_nl(world->gui, errmsg);
-      g_free(errmsg);
-    }
+    start_log_and_display_result(world);
   }
 
   /* We now read the socket */
@@ -827,11 +773,9 @@ close_connection(World *world, gboolean run_hook)
                                           globalPrefs.idxInfoMsgColor);
   ansitextview_append_string(world->gui, "\n");
 
-#ifdef USE_LIBGNUTLS
   if (world->use_tls) {
-    gnutls_bye(world->tls_session);
+    gnutls_bye(world->tls_session, GNUTLS_SHUT_RDWR);
   }
-#endif
 #ifndef __MINGW32__
   close(world->sock);
 #else /* defined __MINGW32__ */
@@ -839,11 +783,9 @@ close_connection(World *world, gboolean run_hook)
 #endif
   world->connected = FALSE;
   world->connecting = FALSE;
-#ifdef USE_LIBGNUTLS
   if (world->use_tls) {
     gnutls_deinit(world->tls_session);
   }
-#endif
 
   if (world->iochan) {
     g_io_channel_unref(world->iochan);
@@ -888,7 +830,6 @@ data_ready_cb(GIOChannel   *iochan,
                   MAX_BUFFER - world->pbuf_size);
   if (nread <= 0) {      /* Connection closed */
     if (nread != 0) {    /* Error */
-#ifdef HAVE_LIBGNUTLS
       if (world->use_tls) {
         if (gnutls_error_is_fatal(nread) == 0) {
           return TRUE;
@@ -897,7 +838,6 @@ data_ready_cb(GIOChannel   *iochan,
         world->errmsg = g_strdup_printf(_("Disconnected from host %s: %s."),
                                         world->host, gnutls_strerror(nread));
       } else {
-#endif
 #ifndef __MINGW32__
         if (errno == EAGAIN || errno == EWOULDBLOCK) {
           return TRUE;
@@ -917,9 +857,7 @@ data_ready_cb(GIOChannel   *iochan,
         world->errmsg = g_strdup_printf(_("Disconnected from host %s: error #%d."),
                                         world->host, errcode);
 #endif
-#ifdef HAVE_LIBGNUTLS
       }
-#endif
     }
     disconnect_world(world, FALSE);
     return FALSE;
@@ -1368,7 +1306,6 @@ write_escaped(World *world, const void *buf, size_t count)
 }
 
 
-#ifdef HAVE_LIBGNUTLS
 ssize_t
 kc_recv(World *world, void *buf, size_t s)
 {
@@ -1389,4 +1326,3 @@ kc_send(World *world, const void *buf, size_t s)
     return send(world->sock, buf, s, 0);
   }
 }
-#endif
