@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ static char *my_argv_static[] = { "kildperl",
 void
 init_perl_system(void)
 {
-  PERL_SYS_INIT(&my_argc_static, &my_argv_static);
+  PERL_SYS_INIT(&my_argc_static, (char ***) &my_argv_static);
 }
 
 
@@ -112,12 +112,12 @@ init_perl_script(World *world)
     my_argv[my_argc] = my_argv_static[my_argc];
   }
   my_argv[my_argc++] = g_strdup_printf("-I%s", get_kildclient_installed_file(""));
-#ifdef __WIN32__
+#ifdef __MINGW32__
   my_argv[my_argc++] = g_strdup_printf("-I%s", get_kildclient_installed_file("perl"));
 #endif
   my_argv[my_argc] = g_strdup(get_kildclient_installed_file("kildclient.pl"));
 
-#ifndef __WIN32__
+#ifndef __MINGW32__
   user_plugin_dir = g_strdup_printf("%s/plugins",
                                     get_kildclient_directory_path());
 #else
@@ -158,7 +158,7 @@ init_perl_script(World *world)
 
   g_free(my_argv[my_argc]);
   g_free(my_argv[my_argc - 1]);
-#ifdef __WIN32__
+#ifdef __MINGW32__
   g_free(my_argv[my_argc - 2]);
 #endif
   g_free(my_argv);
@@ -217,13 +217,7 @@ create_window_var(void)
 void
 destruct_perl_script(PerlInterpreter *perl_interpreter)
 {
-#ifndef __MINGW32__
-  /* For some reason, this function crashes under Windows when a World
-     is closed and there is another one open. I don't know how
-     important it is to call this function, but at least the one that
-     frees the resources is called. */
   perl_destruct(perl_interpreter);
-#endif
   perl_free(perl_interpreter);
 }
 
@@ -535,6 +529,36 @@ World *fetch_world(int items, SV *self_ref, HV **self_to_store)
 }
 
 
+static
+void
+XS_gettext(pTHX_ CV *perlcv)
+{
+  dXSARGS;
+
+  if (items == 0) {
+    XSRETURN_EMPTY;
+  }
+
+  XST_mPV(0, _(SvPV_nolen(ST(0))));
+  XSRETURN(1);
+}
+
+
+static
+void
+XS_ngettext(pTHX_ CV *perlcv)
+{
+  dXSARGS;
+
+  if (items < 3) {
+    XSRETURN_EMPTY;
+  }
+
+  XST_mPV(0, ngettext(SvPV_nolen(ST(0)), SvPV_nolen(ST(1)), SvIV(ST(2))));
+  XSRETURN(1);
+}
+
+
 static
 void
 XS_getclientname(pTHX_ CV *perlcv)
@@ -1199,6 +1223,43 @@ XS_interpret(pTHX_ CV *perlcv)
 }
 
 
+static
+void
+XS_getinput(pTHX_ CV *perlcv)
+{
+  const gchar *text;
+  FETCHWORLDVARS;
+  dXSARGS;
+
+  FETCHWORLD;
+
+  text = simo_combo_box_get_text(world->gui->cmbEntry);
+
+  XST_mPV(0, text);
+  XSRETURN(1);
+}
+
+
+static
+void
+XS_setinput(pTHX_ CV *perlcv)
+{
+  char *input = "";
+  FETCHWORLDVARS;
+  dXSARGS;
+
+  FETCHWORLD;
+
+  if (items > 1) {
+    input = SvPV_nolen(ST(1));
+  }
+
+  simo_combo_box_set_text(world->gui->cmbEntry, input);
+
+  XSRETURN_EMPTY;
+}
+
+
 static
 void
 XS_getline(pTHX_ CV *perlcv)
@@ -1450,7 +1511,7 @@ XS_trigger(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "pattern", 7, FALSE);
         if (value) {
           if (have_pattern) {
-            warn(_("%s: pattern given twice, using the named attribute one"),
+            warn(_("%s: Pattern given twice, using the named attribute one"),
                  "trigger");
           }
           g_free(trigger->pattern);
@@ -1462,7 +1523,7 @@ XS_trigger(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "action", 6, FALSE);
         if (value) {
           if (have_action) {
-            warn(_("%s: action given twice, using the named attribute one"),
+            warn(_("%s: Action given twice, using the named attribute one"),
                  "trigger");
           }
           g_free(trigger->action);
@@ -1528,7 +1589,7 @@ XS_trigger(pTHX_ CV *perlcv)
 
   if (i == -1) {
     if (!have_pattern) {
-      warn(_("%s: pattern not specified, not creating"),
+      warn(_("%s: Pattern not specified, not creating"),
            "trigger");
       if (i == -1) {
         g_free(trigger);
@@ -1537,7 +1598,7 @@ XS_trigger(pTHX_ CV *perlcv)
     }
 
     if (!have_action && !trigger->gag_output && !trigger->gag_log) {
-      warn(_("%s: action not specified, and isn't gag, not creating"),
+      warn(_("%s: Action not specified, and isn't gag, not creating"),
            "trigger");
       if (i == -1) {
         g_free(trigger);
@@ -1596,7 +1657,7 @@ fill_highlight(Trigger *trigger, HV *style)
   if (value) {
     ival = SvIV(*value);
     if (ival < -1) {
-      warn(_("%s: invalid target"), "trigger");
+      warn(_("%s: Invalid target"), "trigger");
     } else {
       trigger->high_target = ival;
     }
@@ -1606,7 +1667,7 @@ fill_highlight(Trigger *trigger, HV *style)
   if (value) {
     ival = SvIV(*value);
     if (ival < -1 || ival > ANSI_N_COLORS_HIGHLIGHT) {
-      warn(_("%s: invalid fg color"), "trigger");
+      warn(_("%s: Invalid fg color"), "trigger");
     } else {
       trigger->high_fg_color = ival;
     }
@@ -1616,7 +1677,7 @@ fill_highlight(Trigger *trigger, HV *style)
   if (value) {
     ival = SvIV(*value);
     if (ival < -1 || ival > ANSI_N_COLORS_HIGHLIGHT) {
-      warn(_("%s: invalid bg color"), "trigger");
+      warn(_("%s: Invalid bg color"), "trigger");
     } else {
       trigger->high_bg_color = ival;
     }
@@ -1626,7 +1687,7 @@ fill_highlight(Trigger *trigger, HV *style)
   if (value) {
     ival = SvIV(*value);
     if (ival < -1 || ival > 2) {
-      warn(_("%s: invalid underline style"), "trigger");
+      warn(_("%s: Invalid underline style"), "trigger");
     } else {
       trigger->high_underline = ival;
     }
@@ -1814,7 +1875,7 @@ XS__getobjectnumber(pTHX_ CV *perlcv)
     break;
 
   case 4:
-    tofind = get_hook_list_for_reading(world, SvPV_nolen(ST(4)), NULL);
+    tofind = get_hook_list_or_warn_if_nonexistent(world, SvPV_nolen(ST(4)));
     if (!tofind) {
       XSRETURN(0);
     }
@@ -1877,7 +1938,7 @@ XS__objectenabled(pTHX_ CV *perlcv)
     break;
 
   case 4:
-    tofind = get_hook_list_for_reading(world, SvPV_nolen(ST(4)), NULL);
+    tofind = get_hook_list_or_warn_if_nonexistent(world, SvPV_nolen(ST(4)));
     if (!tofind) {
       XSRETURN(0);
     }
@@ -1999,7 +2060,7 @@ XS_alias(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "pattern", 7, FALSE);
         if (value) {
           if (have_pattern) {
-            warn(_("%s: pattern given twice, using the named attribute one"),
+            warn(_("%s: Pattern given twice, using the named attribute one"),
                  "alias");
           }
           g_free(alias->pattern);
@@ -2011,7 +2072,7 @@ XS_alias(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "substitution", 12, FALSE);
         if (value) {
           if (have_substitution) {
-            warn(_("%s: substitution given twice, using the named attribute one"),
+            warn(_("%s: Substitution given twice, using the named attribute one"),
                  "alias");
           }
           g_free(alias->substitution);
@@ -2057,7 +2118,7 @@ XS_alias(pTHX_ CV *perlcv)
 
   if (i == -1) {
     if (!have_pattern) {
-      warn(_("alias: not creating alias without pattern"));
+      warn(_("alias: Not creating alias without pattern"));
       if (i == -1) {
         g_free(alias);
       }
@@ -2065,7 +2126,7 @@ XS_alias(pTHX_ CV *perlcv)
     }
 
     if (!have_substitution) {
-      warn(_("alias: not creating alias without substitution"));
+      warn(_("alias: Not creating alias without substitution"));
       if (i == -1) {
         g_free(alias);
       }
@@ -2317,8 +2378,7 @@ XS_macro(pTHX_ CV *perlcv)
   } else {
     macro = (Macro *) g_slist_nth_data(world->macros, i);
     if (!macro) {
-      ansitextview_append_string_nl(world->gui,
-                                    _("macro: No such macro"));
+      ansitextview_append_string_nl(world->gui, _("No such macro"));
       XSRETURN_EMPTY;
     }
   }
@@ -2374,7 +2434,7 @@ XS_macro(pTHX_ CV *perlcv)
           GdkModifierType modifiers;
 
           if (have_key) {
-            warn(_("%s: keycode given twice, using the named attribute one"),
+            warn(_("%s: Keycode given twice, using the named attribute one"),
                  "macro");
           }
 
@@ -2397,7 +2457,7 @@ XS_macro(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "action", 6, FALSE);
         if (value) {
           if (have_action) {
-            warn(_("%s: action given twice, using the named attribute one"),
+            warn(_("%s: Action given twice, using the named attribute one"),
                  "macro");
           }
           g_free(macro->action);
@@ -2430,14 +2490,14 @@ XS_macro(pTHX_ CV *perlcv)
 
   /* Verification of required arguments */
   if (i == -1 && !have_key) {
-    warn(_("%s: keycode not specified, not creating"), "macro");
+    warn(_("%s: Keycode not specified, not creating"), "macro");
     if (i == -1) {
       g_free(macro);
     }
     XSRETURN_EMPTY;
   }
   if (i == -1 && !have_action) {
-    warn(_("%s: action not specified, not creating"), "macro");
+    warn(_("%s: Action not specified, not creating"), "macro");
     if (i == -1) {
       g_free(macro);
     }
@@ -2500,7 +2560,7 @@ XS__listmacro(pTHX_ CV *perlcv)
   ansitextview_append_stringf(world->gui,
                               _("Macro number %d\n"
                                 "  Name:     %s\n"
-                                "  Key Code: %s\n"
+                                "  Key code: %s\n"
                                 "  Action:   %s\n"
                                 "  Enabled:  %s\n"),
                               i,
@@ -2607,8 +2667,7 @@ XS_timer(pTHX_ CV *perlcv)
   } else {
     timer = (Timer *) g_slist_nth_data(world->timers, i);
     if (!timer) {
-      ansitextview_append_string_nl(world->gui,
-                                    _("timer: No such timer"));
+      ansitextview_append_string_nl(world->gui, _("No such timer"));
       XSRETURN_EMPTY;
     }
   }
@@ -2633,7 +2692,7 @@ XS_timer(pTHX_ CV *perlcv)
   value = hv_fetch(attributes, "interval", 8, FALSE);
   if (value) {
     if (!SvNIOK(*value)) {
-      warn(_("%s: interval must be numeric"), "timer");
+      warn(_("%s: Interval must be numeric"), "timer");
       if (i == -1) {
         g_free(timer);
       }
@@ -2646,7 +2705,7 @@ XS_timer(pTHX_ CV *perlcv)
   value = hv_fetch(attributes, "count", 5, FALSE);
   if (value) {
     if (!SvIOK(*value)) {
-      warn(_("%s: count must be numeric"), "timer");
+      warn(_("%s: Count must be numeric"), "timer");
       if (i == -1) {
         g_free(timer);
       }
@@ -2677,14 +2736,14 @@ XS_timer(pTHX_ CV *perlcv)
 
   /* Verification of required arguments */
   if (new_interval == 0 && i == -1) {
-    warn(_("%s: interval not specified, not creating"), "timer");
+    warn(_("%s: Interval not specified, not creating"), "timer");
     if (i == -1) {
       g_free(timer);
     }
     XSRETURN_EMPTY;
   }
   if (new_interval < 0) {
-    warn(_("%s: cannot create timer with negative interval"), "timer");
+    warn(_("%s: Cannot create timer with negative interval"), "timer");
     if (i == -1) {
       g_free(timer);
     }
@@ -2705,7 +2764,7 @@ XS_timer(pTHX_ CV *perlcv)
   }
 
   if (!timer->action) {
-    warn(_("%s: action not specified, not creating"), "timer");
+    warn(_("%s: Action not specified, not creating"), "timer");
     if (i == -1) {
       g_free(timer);
     }
@@ -3075,7 +3134,7 @@ XS_hook(pTHX_ CV *perlcv)
         value = hv_fetch(attributes, "action", 6, FALSE);
         if (value) {
           if (have_action) {
-            warn(_("%s: action given twice, using the named attribute one"),
+            warn(_("%s: Action given twice, using the named attribute one"),
                  "hook");
             g_free(action);
           }
@@ -3203,7 +3262,6 @@ void
 XS_logfile(pTHX_ CV *perlcv)
 {
   char *tmp;
-  char *errmsg = NULL;
   FETCHWORLDVARS;
   dXSARGS;
 
@@ -3235,14 +3293,7 @@ XS_logfile(pTHX_ CV *perlcv)
     g_free(world->log_file_name);
     world->log_file_name = g_strdup(tmp);
 
-    if (start_log(world, 0, &errmsg)) {
-      ansitextview_append_stringf(world->gui,
-                                  _("Logging to file %s.\n"),
-                                  world->log_actual_file);
-    } else {
-      ansitextview_append_string_nl(world->gui, errmsg);
-      g_free(errmsg);
-    }
+    start_log_and_display_result(world);
     break;
   }
 
@@ -3573,6 +3624,9 @@ xs_init()
 
 
   /* Our subroutines */
+  newXS("gettext",  XS_gettext,  "");
+  newXS("ngettext", XS_ngettext, "");
+
   newXS("getclientname", XS_getclientname, "");
   newXS("getversion",    XS_getversion,    "");
   newXS("quit",          XS_quit,          "");
@@ -3607,11 +3661,13 @@ xs_init()
   newXS("World::getconntime",  XS_getconntime,  "World");
   newXS("World::getidletime",  XS_getidletime,  "World");
 
-  newXS("World::echo",            XS_echo,      "World");
-  newXS("World::send",            XS_send,      "World");
-  newXS("World::_mlsend",         XS__mlsend,   "World");
-  newXS("World::interpret",       XS_interpret, "World");
-  newXS("World::getline",         XS_getline,   "World");
+  newXS("World::echo",            XS_echo,            "World");
+  newXS("World::send",            XS_send,            "World");
+  newXS("World::_mlsend",         XS__mlsend,         "World");
+  newXS("World::interpret",       XS_interpret,       "World");
+  newXS("World::getinput",        XS_getinput,        "World");
+  newXS("World::setinput",        XS_setinput,        "World");
+  newXS("World::getline",         XS_getline,         "World");
   newXS("World::_sendserverdata", XS__sendserverdata, "World");
 
   newXS("World::setstatus", XS_setstatus, "World");
