@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,19 +89,12 @@ save_permanent_variables(World *world)
   while (iter) {
     varname = (char *) iter->data;
 
-    /* Not really sure why, but turning off the utf8 flag actually
-       makes the dumping output UTF-8 strings, which later are read
-       correctly. */
     if (varname[0] == '$') {
-      command = g_strdup_printf("Encode::_utf8_off(%s);"
-                                "$__serialized = Data::Dumper->Dump([%s], ['%s']);"
-                                "Encode::_utf8_on(%s)",
-                                varname, varname, varname+1, varname);
+      command = g_strdup_printf("$__serialized = Data::Dumper->Dump([%s], ['%s']);",
+                                varname, varname+1);
     } else {
-      command = g_strdup_printf("map { Encode::_utf8_off($_) } %s;"
-                                "$__serialized = Data::Dumper->Dump([\\%s], ['*%s']);"
-                                "map { Encode::_utf8_on($_) } %s;",
-                                varname, varname, varname+1, varname);
+      command = g_strdup_printf("$__serialized = Data::Dumper->Dump([\\%s], ['*%s']);",
+                                varname, varname+1);
     }
 
     eval_pv(command, TRUE);
@@ -118,17 +111,10 @@ save_permanent_variables(World *world)
   if (!g_file_set_contents(variables_file,
                            file_contents->str, file_contents->len,
                            &error)) {
-    GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                            GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_CLOSE,
-                                            _("Could not open file '%s': %s\n"
-                                              "Variables were not saved."),
-                                            variables_file,
-                                            error->message);
-    gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-    gtk_dialog_run(GTK_DIALOG(dlg));
-    gtk_widget_destroy(dlg);
+    kc_error_dialog(GTK_WINDOW(wndMain),
+                    _("Could not open file '%s': %s\n"
+                      "Variables were not saved."),
+                    variables_file, error->message);
   }
   g_free(variables_file);
   g_string_free(file_contents, TRUE);
