@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
   GObject          *txtProxyPort;
   GObject          *txtProxyUser;
   GObject          *txtProxyPassword;
-#ifndef __WIN32__
+#ifndef __MINGW32__
   GObject          *txtBrowserCommand;
   GObject          *txtAudioPlayerCommand;
 #else
@@ -99,7 +99,7 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
 #endif
 
   if (!dialog) {
-    GError *error     = NULL;
+    GError *error = NULL;
 
     if (!gtk_builder_add_from_file(main_builder,
                                    get_kildclient_installed_file("dlgPreferences.ui"),
@@ -110,6 +110,7 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
     }
 
     dialog = GTK_WIDGET(gtk_builder_get_object(main_builder, "dlgPreferences"));
+    gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(wndMain));
     notebook = GTK_NOTEBOOK(gtk_builder_get_object(main_builder, "ntbkPrefs"));
 
     /* Combos with colors */
@@ -176,7 +177,7 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
       = GTK_COMBO_BOX(gtk_builder_get_object(main_builder, "cmbGProxyType"));
     gtk_combo_box_set_active(cmbProxyType, globalPrefs.proxy.type);
 
-#ifndef __WIN32__
+#ifndef __MINGW32__
     /* Load commands */
     txtBrowserCommand = gtk_builder_get_object(main_builder, "txtBrowserCommand");
     gtk_entry_set_text(GTK_ENTRY(txtBrowserCommand),
@@ -191,7 +192,7 @@ show_preferences_dialog_cb(GtkMenuItem *widget, gpointer data)
     g_signal_connect(txtAudioPlayerCommand, "focus_out_event",
                      G_CALLBACK(txt_cmd_focus_out_cb),
                      &globalPrefs.audio_player_command);
-#else /* defined __WIN32__ */
+#else /* defined __MINGW32__ */
     tabPrograms
       = GTK_WIDGET(gtk_builder_get_object(main_builder, "prefs_panel_progs"));
     gtk_notebook_remove_page(notebook,
@@ -438,16 +439,9 @@ save_global_preferences(void)
   if (!g_file_set_contents(filepath,
                            file_contents->str, file_contents->len,
                            &error)) {
-    GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                            GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_CLOSE,
-                                            _("Could not open file '%s': %s"),
-                                            filepath,
-                                            error->message);
-    gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Error"));
-    gtk_dialog_run(GTK_DIALOG(dlg));
-    gtk_widget_destroy(dlg);
+    kc_error_dialog(GTK_WINDOW(wndMain),
+                    _("Could not open file '%s': %s"),
+                    filepath, error->message);
   }
 
   g_free(filepath);
@@ -517,16 +511,9 @@ create_kildclient_directory(void)
 
   if (stat(kilddir, &stinfo) == -1) {
     if (g_mkdir(kilddir, S_IRUSR | S_IWUSR | S_IXUSR) == -1) {
-      GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              GTK_MESSAGE_ERROR,
-                                              GTK_BUTTONS_CLOSE,
-                                              _("Could not create directory '%s': %s"),
-                                              kilddir,
-                                              g_strerror(errno));
-      gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Error"));
-      gtk_dialog_run(GTK_DIALOG(dlg));
-      gtk_widget_destroy(dlg);
+      kc_error_dialog(GTK_WINDOW(wndMain),
+                      _("Could not create directory '%s': %s"),
+                      kilddir, g_strerror(errno));
       return NULL;
     }
   }
