@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -235,7 +235,7 @@ we_alias_configure_view(GtkTreeView *view, GtkTreeModel *model)
                    G_CALLBACK(we_guied_bool_col_toggled_cb), view);
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(column, TRUE);
-  gtk_tree_view_column_set_title(column, _("I. Case"));
+  gtk_tree_view_column_set_title(column, _("Ig. case"));
   gtk_tree_view_column_pack_start(column, renderer, FALSE);
   gtk_tree_view_column_set_cell_data_func(column,
                                           renderer,
@@ -376,8 +376,8 @@ we_alias_delete_cb(GtkButton *button, gpointer data)
 
     n = gtk_tree_selection_count_selected_rows(selection);
     msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                n,
-                                                _("alias"), _("aliases"));
+                                                ngettext("alias", "aliases", n),
+                                                n);
 
     if (!world->confirm_delete
         || gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
@@ -459,7 +459,10 @@ edit_alias(World *world, Alias *alias)
 
   dlgEditAlias
     = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditAlias"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditAlias),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditAlias), GTK_RESPONSE_OK);
+
   txtName
     = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtAliasName"));
   txtPattern
@@ -509,27 +512,15 @@ edit_alias(World *world, Alias *alias)
 
       newpattern = gtk_entry_get_text(txtPattern);
       if (strcmp(newpattern, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditAlias),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the pattern."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditAlias),
+                        _("You must specify the pattern."));
         continue;
       }
 
       newsubstitution = gtk_entry_get_text(txtSubstitution);
       if (strcmp(newsubstitution, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditAlias),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the substitution."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditAlias),
+                        _("You must specify the substitution."));
         continue;
       }
 
