@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -139,11 +139,7 @@ fill_we_general_tab(World *world, GtkBuilder *ui_builder)
   if (world->port) {
     gtk_entry_set_text(txtPort, world->port);
   }
-#ifdef HAVE_LIBGNUTLS
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chkTLS), world->use_tls);
-#else
-  gtk_widget_destroy(chkTLS);
-#endif
 
   /* Proxy */
   /* -1 is "global settings in enumeration */
@@ -193,9 +189,7 @@ update_we_general_parameters(World *world, GtkBuilder *ui_builder)
   GtkEntry        *txtProxyUser;
   GtkEntry        *txtProxyPassword;
   GtkComboBox     *cmbConnStyle;
-#ifdef HAVE_LIBGNUTLS
   GtkToggleButton *chkTLS;
-#endif
 
   txtName          = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtName"));
   txtHost          = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtHost"));
@@ -263,10 +257,8 @@ update_we_general_parameters(World *world, GtkBuilder *ui_builder)
   /* Auto-logon */
   world->connection_style = gtk_combo_box_get_active(cmbConnStyle);
 
-#ifdef HAVE_LIBGNUTLS
   chkTLS = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkTLS"));
   world->use_tls = gtk_toggle_button_get_active(chkTLS);
-#endif
 }
 
 
@@ -345,7 +337,10 @@ edit_char(World *world, GtkTreeModel *model, GtkTreeIter *iter)
   }
 
   dlgEditChar = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditChar"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditChar),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditChar), GTK_RESPONSE_OK);
+
   txtName     = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtCharName"));
   txtPassword = GTK_ENTRY( gtk_builder_get_object(ui_builder,
                                                   "txtCharPassword"));
@@ -374,27 +369,15 @@ edit_char(World *world, GtkTreeModel *model, GtkTreeIter *iter)
       /* Validate */
       newname = gtk_entry_get_text(txtName);
       if (strcmp(newname, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditChar),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the name."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditChar),
+                        _("You must specify the name."));
         continue;
       }
 
       newpassword = gtk_entry_get_text(txtPassword);
       if (strcmp(newpassword, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditChar),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the password."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditChar),
+                        _("You must specify the password."));
         continue;
       }
 
@@ -432,8 +415,7 @@ we_general_delete_char_cb(GtkWidget *widget, gpointer data)
     GtkWidget *msgdlg;
 
     msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                1,
-                                                _("character"), "");
+                                                _("character"), 1);
 
     if (!world->confirm_delete
         || gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
