@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,6 +101,8 @@ we_guied_export_cb(GtkButton *button, gpointer data)
                                             NULL);
   gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(filechooser),
                                     ExtraFilechooser);
+
+  gtk_widget_show_all(GTK_WIDGET(filechooser));
   if (gtk_dialog_run(GTK_DIALOG(filechooser)) == GTK_RESPONSE_YES) {
     gchar *filename;
 
@@ -305,16 +307,9 @@ we_guied_do_export(World *world, const gchar *file, GtkBuilder *ui_builder)
   if (!g_file_set_contents(file,
                            file_contents->str, file_contents->len,
                            &error)) {
-    GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                            GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_CLOSE,
-                                            _("Could not open file '%s': %s"),
-                                            file,
-                                            error->message);
-    gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Error"));
-    gtk_dialog_run(GTK_DIALOG(dlg));
-    gtk_widget_destroy(dlg);
+    kc_error_dialog(GTK_WINDOW(world->dlgEditWorld),
+                    _("Could not open file '%s': %s"),
+                    file, error->message);
   }
   g_string_free(file_contents, TRUE);
 }
@@ -394,16 +389,9 @@ we_guied_do_import(World *world, const gchar *filename)
   newworld = create_new_world(FALSE);
   success = load_world_from_file(filename, newworld, FALSE, &error);
   if (!success) {
-    GtkWidget *msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                               GTK_DIALOG_DESTROY_WITH_PARENT,
-                                               GTK_MESSAGE_ERROR,
-                                               GTK_BUTTONS_CLOSE,
-                                               _("Could not import file '%s': %s"),
-                                               filename,
-                                               error->message);
-    gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Error"));
-    gtk_dialog_run(GTK_DIALOG(msgdlg));
-    gtk_widget_destroy(msgdlg);
+    kc_error_dialog(GTK_WINDOW(world->dlgEditWorld),
+                    _("Could not import file '%s': %s"),
+                    filename, error->message);
     free_world(newworld);
     return;
   }
@@ -948,32 +936,23 @@ we_guied_selection_changed_cb(GtkTreeSelection *selection,
 
 GtkWidget *
 we_guied_confirm_delete_dialog_new(GtkWindow   *parent,
-                                   int          n,
-                                   const gchar *singular,
-                                   const gchar *plural)
+                                   const gchar *objname,
+                                   int          n)
 {
   GtkWidget *msgdlg;
 
-  if (n == 1) {
-    msgdlg = gtk_message_dialog_new(parent,
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_QUESTION,
-                                    GTK_BUTTONS_NONE,
-                                    _("Do you really want to delete the %s?"),
-                                    singular);
-  } else {
-    msgdlg = gtk_message_dialog_new(parent,
-                                    GTK_DIALOG_MODAL,
-                                    GTK_MESSAGE_QUESTION,
-                                    GTK_BUTTONS_NONE,
-                                    _("Do you really want to delete %d %s?"),
-                                    n,
-                                    plural);
-  }
+  msgdlg = gtk_message_dialog_new(parent,
+                                  GTK_DIALOG_MODAL,
+                                  GTK_MESSAGE_QUESTION,
+                                  GTK_BUTTONS_NONE,
+                                  ngettext("Do you really want to delete the %1$s?",
+                                           "Do you really want to delete %2$d %1$s?",
+                                           n),
+                                  objname, n);
   gtk_window_set_title(GTK_WINDOW(msgdlg), _("Confirm deletion"));
   gtk_dialog_add_buttons(GTK_DIALOG(msgdlg),
-                         _("Do not delete"), GTK_RESPONSE_NO,
-                         _("Delete"), GTK_RESPONSE_YES,
+                         _("Do _not delete"), GTK_RESPONSE_NO,
+                         _("_Delete"), GTK_RESPONSE_YES,
                          NULL);
 
   return msgdlg;
