@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -543,15 +543,15 @@ we_hook_delete_cb(GtkButton *button, gpointer data)
 
     n = gtk_tree_selection_count_selected_rows(selection);
     msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                n,
-                                                _("hook"), _("hooks"));
+                                                ngettext("hook", "hooks", n),
+                                                n);
 
     if (!world->confirm_delete
         || gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
       GList *listiter = g_list_last(selected);
 
       event = g_object_get_data(G_OBJECT(model), "forevent");
-      hooklist = get_hook_list_for_reading(world, event, NULL);
+      get_hook_list_for_reading(world, event, &hooklist, NULL);
       while (listiter) {
         gtk_tree_model_get_iter(model, &iter, listiter->data);
         gtk_tree_model_get(model, &iter, WE_GUIED_POINTER, &hook, -1);
@@ -623,8 +623,11 @@ edit_hook(World *world, const gchar *event, Hook *hook)
   }
 
   dlgEditHook = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditHook"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditHook),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditHook),
                                   GTK_RESPONSE_OK);
+
   lblEvent    = GTK_LABEL(gtk_builder_get_object(ui_builder,
                                                  "lblHookEvent"));
   txtName     = GTK_ENTRY(gtk_builder_get_object(ui_builder,
@@ -664,14 +667,8 @@ edit_hook(World *world, const gchar *event, Hook *hook)
       /* Validate */
       newaction = gtk_entry_get_text(txtAction);
       if (strcmp(newaction, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditHook),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the action."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditHook),
+                        _("You must specify the action."));
         continue;
       }
 
@@ -748,7 +745,7 @@ we_hook_move_cb(GtkButton *button, gpointer data)
     gtk_tree_model_get_iter(model, &iter, selected->data);
     gtk_tree_model_get(model, &iter, WE_GUIED_POINTER, &hook, -1);
     event = g_object_get_data(G_OBJECT(model), "forevent");
-    hooklist = get_hook_list_for_reading(world, event, &hook_pos);
+    get_hook_list_for_reading(world, event, &hooklist, &hook_pos);
     pos = g_slist_index(hooklist, hook);
     new_pos = pos;
     if (is_up) {
