@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "libintl-wrapper.h"
 #include <gtk/gtk.h>
 #include <gmodule.h>
+#include <gtkspell/gtkspell.h>
 
 #include "simocombobox.h"
 
@@ -35,6 +36,9 @@
 /***********************
  * Function prototypes *
  ***********************/
+static void fill_spell_languages_combo(GtkBuilder *ui_builder);
+static void fill_spell_checking(World *world, GtkBuilder *ui_builder);
+
 /* XML UI signals */
 G_MODULE_EXPORT void multi_line_toggled_cb(GtkToggleButton *button,
                                            gpointer         data);
@@ -50,14 +54,37 @@ G_MODULE_EXPORT void flood_prevention_toggled_cb(GtkToggleButton *chkbox,
 GObject *
 get_we_input_tab(GtkBuilder *ui_builder)
 {
-  GObject *panel;
+  GObject         *panel;
 
   panel = gtk_builder_get_object(ui_builder, "we_panel_input");
 
+  fill_spell_languages_combo(ui_builder);
+
   return panel;
 }
 
 
+static
+void
+fill_spell_languages_combo(GtkBuilder *ui_builder)
+{
+  GtkComboBoxText *cmbSpellLanguage;
+  GList           *languages;
+  GList           *i;
+
+  cmbSpellLanguage
+    = GTK_COMBO_BOX_TEXT(gtk_builder_get_object(ui_builder,
+                                                "cmbSpellLanguage"));
+
+  languages = gtk_spell_checker_get_language_list();
+  for (i = languages; i != NULL; i = i->next) {
+    gtk_combo_box_text_append_text(cmbSpellLanguage, i->data);
+  }
+
+  g_list_free(languages);
+}
+
+
 void
 fill_we_input_tab(World *world, GtkBuilder *ui_builder)
 {
@@ -72,8 +99,6 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
   GtkSpinButton   *spnNLines;
   GtkToggleButton *chkAutoCompletion;
   GtkSpinButton   *spnMinPrefix;
-  GtkToggleButton *chkSpell;
-  GtkEntry        *txtSpellLanguage;
   GtkFontButton   *entryfont_btn;
   GObject         *chkFloodPrevention;
   GtkWidget       *spnMaxCommands;
@@ -104,10 +129,6 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
     = GTK_SPIN_BUTTON(gtk_builder_get_object(ui_builder, "spnMinPrefix"));
   spnNLines
     = GTK_SPIN_BUTTON(gtk_builder_get_object(ui_builder, "spnNLines"));
-  chkSpell
-    = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkSpell"));
-  txtSpellLanguage
-    = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtSpellLanguage"));
   txtCommandSeparator
     = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtCommandSeparator"));
   entryfont_btn
@@ -132,12 +153,7 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
   gtk_toggle_button_set_active(chkAutoCompletion, world->autocompletion);
   gtk_spin_button_set_value(spnMinPrefix, world->autocompl_minprefix);
 
-  gtk_toggle_button_set_active(chkSpell, world->spell);
-  if (world->spell_language) {
-    gtk_entry_set_text(txtSpellLanguage, world->spell_language);
-  } else {
-    gtk_entry_set_text(txtSpellLanguage, "");
-  }
+  fill_spell_checking(world, ui_builder);
 
   gtk_font_button_set_font_name(entryfont_btn, world->entryfont);
 
@@ -156,6 +172,55 @@ fill_we_input_tab(World *world, GtkBuilder *ui_builder)
 }
 
 
+static
+void
+fill_spell_checking(World *world, GtkBuilder *ui_builder)
+{
+  GtkToggleButton *chkSpell;
+  GtkComboBox     *cmbSpellLanguage;
+
+  chkSpell
+    = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkSpell"));
+  cmbSpellLanguage
+    = GTK_COMBO_BOX(gtk_builder_get_object(ui_builder, "cmbSpellLanguage"));
+
+  gtk_toggle_button_set_active(chkSpell, world->spell);
+  if (world->spell_language) {
+    GtkTreeModel *model;
+    GtkTreeIter   i;
+    gboolean      has_more;
+    gboolean      found;
+    gint          index;
+
+    model = gtk_combo_box_get_model(cmbSpellLanguage);
+    index = 0;
+    has_more = gtk_tree_model_get_iter_first(model, &i);
+    while (has_more) {
+      gchar *language;
+
+      gtk_tree_model_get(model, &i, 0, &language, -1);
+      if (strcmp(language, world->spell_language) == 0) {
+        g_free(language);
+        found = TRUE;
+        break;
+      }
+
+      g_free(language);
+      ++index;
+      has_more = gtk_tree_model_iter_next(model, &i);
+    }
+
+    if (found) {
+      gtk_combo_box_set_active(cmbSpellLanguage, index);
+    } else {
+      gtk_combo_box_set_active(cmbSpellLanguage, -1);
+    }
+  } else {
+    gtk_combo_box_set_active(cmbSpellLanguage, -1);
+  }
+}
+
+
 
 void
 update_we_input_parameters(World *world, GtkBuilder *ui_builder)
@@ -171,11 +236,12 @@ update_we_input_parameters(World *world, GtkBuilder *ui_builder)
   GtkToggleButton *chkAutoCompletion;
   GtkSpinButton   *spnMinPrefix;
   GtkToggleButton *chkSpell;
-  GtkEntry        *txtSpellLanguage;
+  GtkComboBoxText *cmbSpellLanguage;
   GtkEntry        *txtCommandSeparator;
 
   GtkEntryCompletion *completion;
-  const gchar        *newval;
+  gchar              *new_language;
+  const gchar        *new_separator;
 
   /* Get widgets */
   chkRepeatCommands
@@ -194,8 +260,9 @@ update_we_input_parameters(World *world, GtkBuilder *ui_builder)
     = GTK_SPIN_BUTTON(gtk_builder_get_object(ui_builder, "spnMinPrefix"));
   chkSpell
     = GTK_TOGGLE_BUTTON(gtk_builder_get_object(ui_builder, "chkSpell"));
-  txtSpellLanguage
-    = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtSpellLanguage"));
+  cmbSpellLanguage
+    = GTK_COMBO_BOX_TEXT(gtk_builder_get_object(ui_builder,
+                                                "cmbSpellLanguage"));
   txtCommandSeparator
     = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtCommandSeparator"));
   chkFloodPrevention
@@ -237,10 +304,11 @@ update_we_input_parameters(World *world, GtkBuilder *ui_builder)
 
   world->spell = gtk_toggle_button_get_active(chkSpell);
   g_free(world->spell_language);
-  newval = gtk_entry_get_text(txtSpellLanguage);
-  if (strcmp(newval, "") != 0) {
-    world->spell_language = g_strdup(newval);
+  new_language = gtk_combo_box_text_get_active_text(cmbSpellLanguage);
+  if (new_language != NULL && strcmp(new_language, "") != 0) {
+    world->spell_language = new_language;
   } else {
+    g_free(new_language);
     world->spell_language = NULL;
   }
   if (world->gui) {
@@ -256,11 +324,11 @@ update_we_input_parameters(World *world, GtkBuilder *ui_builder)
   world->max_equal_commands =
     gtk_spin_button_get_value_as_int(spnMaxCommands);
 
-  newval = gtk_entry_get_text(txtPreventionCommand);
+  new_separator = gtk_entry_get_text(txtPreventionCommand);
   if (!world->flood_prevention_command
-      || strcmp(world->flood_prevention_command, newval) != 0) {
+      || strcmp(world->flood_prevention_command, new_separator) != 0) {
     g_free(world->flood_prevention_command);
-    world->flood_prevention_command = g_strdup(newval);
+    world->flood_prevention_command = g_strdup(new_separator);
   }
 }
 
@@ -333,17 +401,14 @@ input_size_changed_cb(GtkSpinButton *button, gpointer data)
 void
 entryfont_set_cb(GtkFontButton *font_btn, gpointer data)
 {
-  PangoFontDescription *fontDesc;
-  World                *world  = (World *) data;
-  WorldGUI             *gui    = world->gui;
+  World    *world = (World *) data;
+  WorldGUI *gui   = world->gui;
 
   free(world->entryfont);
   world->entryfont = g_strdup(gtk_font_button_get_font_name(font_btn));
 
   if (gui) {
-    fontDesc = pango_font_description_from_string(world->entryfont);
-    simo_combo_box_set_entry_font(gui->cmbEntry, fontDesc);
-    pango_font_description_free(fontDesc);
+    configure_css(gui, world);
   }
 }
 
