@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -201,14 +201,9 @@ we_splugin_add_cb(gpointer data, GtkButton *button)
     }
     g_free(filename);
     if (error) {
-      GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                              GTK_DIALOG_MODAL,
-                                              GTK_MESSAGE_ERROR,
-                                              GTK_BUTTONS_OK,
-                                              "%s", error->message);
-      gtk_window_set_title(GTK_WINDOW(dlg), _("Error Loading Plugin"));
-      gtk_dialog_run(GTK_DIALOG(dlg));
-      gtk_widget_destroy(dlg);
+      kc_error_dialog_with_title(GTK_WINDOW(world->dlgEditWorld),
+                                 _("Error loading plugin"),
+                                 "%s", error->message);
       g_error_free(error);
     }
   }
@@ -458,14 +453,9 @@ we_lplugin_load_cb(gpointer data, GtkButton *button)
       load_plugin(world, filename, &error);
     }
     if (error) {
-      GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                              GTK_DIALOG_MODAL,
-                                              GTK_MESSAGE_ERROR,
-                                              GTK_BUTTONS_OK,
-                                              "%s", error->message);
-      gtk_window_set_title(GTK_WINDOW(dlg), _("Error Loading Plugin"));
-      gtk_dialog_run(GTK_DIALOG(dlg));
-      gtk_widget_destroy(dlg);
+      kc_error_dialog_with_title(GTK_WINDOW(world->dlgEditWorld),
+                                 _("Error loading plugin"),
+                                 "%s", error->message);
       g_error_free(error);
     }
   }
@@ -505,7 +495,7 @@ we_lplugin_help_cb(gpointer data, GtkButton *button)
                                       GTK_MESSAGE_INFO,
                                       GTK_BUTTONS_OK,
                                       _("The help is displayed in main window."));
-      gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Information"));
+      gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient information"));
       chk = gtk_check_button_new_with_mnemonic(_("_Do not display this message again"));
       gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(msgdlg))),
                          chk,
@@ -592,7 +582,7 @@ we_plugin_get_load_filechooser(GtkWindow *parent)
   gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(filechooser),
                                        plugindir,
                                        NULL);
-#ifndef __WIN32__
+#ifndef __MINGW32__
   plugindir = g_strdup_printf("%s/plugins",
                               get_kildclient_directory_path());
 #else
