@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -377,8 +377,8 @@ we_timer_delete_cb(GtkButton *button, gpointer data)
 
     n = gtk_tree_selection_count_selected_rows(selection);
     msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                n,
-                                                _("timer"), _("timers"));
+                                                ngettext("timer", "timers", n),
+                                                n);
 
     if (!world->confirm_delete
         || gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
@@ -435,7 +435,8 @@ edit_timer(World *world, Timer *timer, gboolean editing)
 {
   GtkBuilder      *ui_builder;
   gchar           *objects[] = { "dlgEditTimer",
-                                 "adjustment1", "adjustment2", NULL };
+                                 "adjSpnTimerInterval", "adjSpnTimerCount",
+                                 NULL };
   GError          *error = NULL;
   GtkWidget       *dlgEditTimer;
   GtkEntry        *txtName;
@@ -460,7 +461,10 @@ edit_timer(World *world, Timer *timer, gboolean editing)
   }
 
   dlgEditTimer = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditTimer"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditTimer),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditTimer), GTK_RESPONSE_OK);
+
   txtName      = GTK_ENTRY(gtk_builder_get_object(ui_builder,
                                                   "txtTimerName"));
   txtAction    = GTK_ENTRY(gtk_builder_get_object(ui_builder,
@@ -508,27 +512,15 @@ edit_timer(World *world, Timer *timer, gboolean editing)
 
       newinterval = gtk_spin_button_get_value(spnInterval);
       if (newinterval <= 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditTimer),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("The interval must be positive."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditTimer),
+                        _("The interval must be positive."));
         continue;
       }
 
       newaction = gtk_entry_get_text(txtAction);
       if (strcmp(newaction, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditTimer),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the action."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditTimer),
+                        _("You must specify the action."));
         continue;
       }
 
