@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ get_we_triggers_tab(World *world)
   /* Add an extra button for "Test Triggers" */
   vbox = GTK_BOX(gtk_builder_get_object(ui_builder,
                                         "vbox_int_generic_graphical_editor"));
-  btnTest = gtk_button_new_with_label(_("Test Triggers"));
+  btnTest = gtk_button_new_with_mnemonic(_("_Test triggers"));
   g_signal_connect_swapped(G_OBJECT(btnTest), "clicked",
                            G_CALLBACK(open_test_triggers_dialog), world);
   /* Only enable it if connected */
@@ -254,7 +254,7 @@ we_trigger_configure_view(GtkTreeView *view, GtkTreeModel *model)
                    G_CALLBACK(we_guied_bool_col_toggled_cb), view);
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(column, TRUE);
-  gtk_tree_view_column_set_title(column, _("I. Case"));
+  gtk_tree_view_column_set_title(column, _("Ig. case"));
   gtk_tree_view_column_pack_start(column, renderer, FALSE);
   gtk_tree_view_column_set_cell_data_func(column,
                                           renderer,
@@ -304,7 +304,7 @@ we_trigger_configure_view(GtkTreeView *view, GtkTreeModel *model)
                    G_CALLBACK(we_guied_bool_col_toggled_cb), view);
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(column, TRUE);
-  gtk_tree_view_column_set_title(column, _("Gag Log"));
+  gtk_tree_view_column_set_title(column, _("Gag log"));
   gtk_tree_view_column_pack_start(column, renderer, FALSE);
   gtk_tree_view_column_set_cell_data_func(column,
                                           renderer,
@@ -322,7 +322,7 @@ we_trigger_configure_view(GtkTreeView *view, GtkTreeModel *model)
                    G_CALLBACK(we_guied_bool_col_toggled_cb), view);
   column = gtk_tree_view_column_new();
   gtk_tree_view_column_set_resizable(column, TRUE);
-  gtk_tree_view_column_set_title(column, _("Keep Exec"));
+  gtk_tree_view_column_set_title(column, _("Keep exec"));
   gtk_tree_view_column_pack_start(column, renderer, FALSE);
   gtk_tree_view_column_set_cell_data_func(column,
                                           renderer,
@@ -467,8 +467,8 @@ we_trigger_delete_cb(GtkButton *button, gpointer data)
 
     n = gtk_tree_selection_count_selected_rows(selection);
     msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                                n,
-                                                _("trigger"), _("triggers"));
+                                                ngettext("trigger", "triggers", n),
+                                                n);
     if (!world->confirm_delete
         || gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
       GList *listiter = g_list_last(selected);
@@ -558,6 +558,8 @@ edit_trigger(World *world, Trigger *trigger)
 
   dlgEditTrigger = GTK_WIDGET(gtk_builder_get_object(ui_builder,
                                                      "dlgEditTrigger"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditTrigger),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditTrigger),
                                   GTK_RESPONSE_OK);
 
@@ -584,6 +586,7 @@ edit_trigger(World *world, Trigger *trigger)
                                                           "chkTriggerEnabled"));
 
   g_object_set_data(btnConfigH, "trigger", trigger);
+  g_object_set_data(btnConfigH, "parent-window", dlgEditTrigger);
 
   /* Only display note when editing a plugin's trigger */
   if (!trigger->owner_plugin) {
@@ -628,28 +631,16 @@ edit_trigger(World *world, Trigger *trigger)
 
       newpattern = gtk_entry_get_text(txtPattern);
       if (strcmp(newpattern, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditTrigger),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the pattern."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditTrigger),
+                        _("You must specify the pattern."));
         continue;
       }
 
       newaction = gtk_entry_get_text(txtAction);
       if (strcmp(newaction, "") == 0
           && !newgag && !newgaglog && !newhighlight) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditTrigger),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify the action, unless the trigger is a gag or changes the style."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditTrigger),
+                        _("You must specify the action, unless the trigger is a gag or changes the style."));
         continue;
       }
 
@@ -727,10 +718,11 @@ we_trigger_btnconfigh_cb(GtkWidget *widget, gpointer data)
   Trigger         *trigger;
   GtkBuilder      *ui_builder;
   gchar           *objects[] = { "dlgEditTriggerHighlight",
-                                 "model1", "model2", "model3", "model4",
-                                 "model5", "adjustment3", NULL };
+                                 "modelColors", "modelUnderline",
+                                 "modelYesNo", "adjSpnTarget", NULL };
   GError          *error = NULL;
   GtkWidget       *dlgEditHighlight;
+  GtkWindow       *parent;
   GtkToggleButton *radTargetLine;
   GtkToggleButton *radTargetMatch;
   GtkToggleButton *radTargetSubstring;
@@ -742,6 +734,7 @@ we_trigger_btnconfigh_cb(GtkWidget *widget, gpointer data)
   GtkComboBox     *cmbUnderline;
 
   trigger = g_object_get_data(G_OBJECT(widget), "trigger");
+  parent  = g_object_get_data(G_OBJECT(widget), "parent-window");
 
   ui_builder = gtk_builder_new();
   if (!gtk_builder_add_objects_from_file(ui_builder,
@@ -754,6 +747,7 @@ we_trigger_btnconfigh_cb(GtkWidget *widget, gpointer data)
   }
   dlgEditHighlight
     = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditTriggerHighlight"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditHighlight), parent);
 
   cmbFgColor = GTK_COMBO_BOX(gtk_builder_get_object(ui_builder, "cmbFgColor"));
   cmbBgColor = GTK_COMBO_BOX(gtk_builder_get_object(ui_builder, "cmbBgColor"));
