@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ get_we_vars_tab(World *world)
 
   lblType = GTK_LABEL(gtk_builder_get_object(ui_builder, "lblGEType"));
   gtk_label_set_markup(lblType,
-                       "<span weight=\"bold\">Permanent Variables</span>");
+                       "<span weight=\"bold\">Permanent variables</span>");
 
   btnAdd = gtk_builder_get_object(ui_builder, "btnGEAdd");
   g_signal_connect(btnAdd, "clicked",
@@ -271,24 +271,18 @@ we_var_delete_cb(GtkButton *button, gpointer data)
     gint       n;
 
     n = gtk_tree_selection_count_selected_rows(selection);
-    if (n == 1) {
-      msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_QUESTION,
-                                      GTK_BUTTONS_NONE,
-                                      _("Do you really want to make the variable temporary?"));
-    } else {
-      msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_QUESTION,
-                                      GTK_BUTTONS_NONE,
-                                      _("Do you really want to make %d variables temporary?"),
-                                      n);
-    }
+    msgdlg = gtk_message_dialog_new(GTK_WINDOW(world->dlgEditWorld),
+                                    GTK_DIALOG_MODAL,
+                                    GTK_MESSAGE_QUESTION,
+                                    GTK_BUTTONS_NONE,
+                                    ngettext("Do you really want to make the variable temporary?",
+                                             "Do you really want to make %d variables temporary?",
+                                             n),
+                                    n);
     gtk_window_set_title(GTK_WINDOW(msgdlg), _("Confirm deletion"));
     gtk_dialog_add_buttons(GTK_DIALOG(msgdlg),
-                           _("Keep permanent"), GTK_RESPONSE_NO,
-                           _("Make temporary"), GTK_RESPONSE_YES,
+                           _("Keep _permanent"), GTK_RESPONSE_NO,
+                           _("Make _temporary"), GTK_RESPONSE_YES,
                            NULL);
 
     if (!world->confirm_delete
@@ -370,7 +364,10 @@ edit_var(World *world, const gchar *var)
     return NULL;
   }
   dlgEditVar = GTK_WIDGET(gtk_builder_get_object(ui_builder, "dlgEditVar"));
+  gtk_window_set_transient_for(GTK_WINDOW(dlgEditVar),
+                               GTK_WINDOW(world->dlgEditWorld));
   gtk_dialog_set_default_response(GTK_DIALOG(dlgEditVar), GTK_RESPONSE_OK);
+
   txtName    = GTK_ENTRY(gtk_builder_get_object(ui_builder, "txtVarName"));
 
   /* We don't need it anymore */
@@ -388,26 +385,14 @@ edit_var(World *world, const gchar *var)
       /* Validate */
       givenname = gtk_entry_get_text(txtName);
       if (strcmp(givenname, "") == 0) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditVar),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("You must specify a variable name."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditVar),
+                        _("You must specify a variable name."));
         continue;
       }
 
       if (givenname[0] != '$' && givenname[0] != '@' && givenname[0] != '%') {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditVar),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("Only scalar ($), array (@) and hash (%%) variables can be made permanent."));
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditVar),
+                        _("Only scalar ($), array (@) and hash (%%) variables can be made permanent."));
         continue;
       }
 
@@ -419,15 +404,8 @@ edit_var(World *world, const gchar *var)
           g_slist_find_custom(world->permanent_variables,
                               givenname,
                               (GCompareFunc) strcmp)) {
-        GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(dlgEditVar),
-                                                GTK_DIALOG_MODAL,
-                                                GTK_MESSAGE_ERROR,
-                                                GTK_BUTTONS_OK,
-                                                _("%s is already permanent."),
-                                                givenname);
-        gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Warning"));
-        gtk_dialog_run(GTK_DIALOG(dlg));
-        gtk_widget_destroy(dlg);
+        kc_error_dialog(GTK_WINDOW(dlgEditVar),
+                        _("%s is already permanent."), givenname);
         continue;
       }
 
