@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,11 +44,11 @@ enum {
 /***********************
  * Function prototypes *
  ***********************/
-static GtkWidget    *create_edit_world_dialog(World *world,
+static void          create_edit_world_dialog(World *world,
                                               GtkWindow  *parent);
-static GtkTreeStore *create_model(GtkNotebook *notebook,
-                                  World       *world,
-                                  GtkBuilder  *ui_builder);
+static GtkTreeStore *create_model(GtkStack   *stack,
+                                  World      *world,
+                                  GtkBuilder *ui_builder);
 static void          list_selection_changed_cb(GtkTreeSelection *selection,
                                                gpointer data);
 static GtkWidget    *new_descriptive_panel(const char *title,
@@ -79,7 +79,7 @@ edit_world(World     **world,
   }
 
   if (!((*world)->dlgEditWorld)) {
-    (*world)->dlgEditWorld = create_edit_world_dialog(*world, parent);
+    create_edit_world_dialog(*world, parent);
     gtk_widget_show_all((*world)->dlgEditWorld);
   }
   g_object_set_data(G_OBJECT((*world)->dlgEditWorld),
@@ -115,13 +115,13 @@ world_editor_response_cb(GtkWidget *dialog, gint response, gpointer data)
     if (world != default_world) {
       update_we_general_parameters(world, ui_builder);
     }
+    update_we_mainwindow_parameters(world, ui_builder);
     update_we_input_parameters(world, ui_builder);
     update_we_logging_parameters(world, ui_builder);
     if (world != default_world) {
       update_we_scripting_parameters(world, ui_builder);
     }
     update_we_protocols_parameters(world, ui_builder);
-    update_we_misc_parameters(world, ui_builder);
     newworld = g_object_get_data(G_OBJECT(dialog), "newworldptr");
     update_we_advanced_parameters(world, newworld, ui_builder);
 
@@ -147,7 +147,6 @@ world_editor_response_cb(GtkWidget *dialog, gint response, gpointer data)
       fill_we_scripting_tab(world, ui_builder);
     }
     fill_we_protocols_tab(world, ui_builder);
-    fill_we_misc_tab(world, ui_builder);
     fill_we_advanced_tab(world, ui_builder);
   }
 
@@ -156,13 +155,12 @@ world_editor_response_cb(GtkWidget *dialog, gint response, gpointer data)
 
 
 static
-GtkWidget *
+void
 create_edit_world_dialog(World *world, GtkWindow *parent)
 {
   GError      *error = NULL;
-  GtkWidget   *dlgEditWorld;
   GtkTreeView *treeView;
-  GtkNotebook *notebook;
+  GtkStack    *stack;
 
   GtkTreeStore      *model;
   GtkCellRenderer   *renderer;
@@ -179,21 +177,19 @@ create_edit_world_dialog(World *world, GtkWindow *parent)
                                  &error)) {
     g_warning(_("Error loading UI from XML file: %s"), error->message);
     g_error_free(error);
-    return NULL; /* This will cause warnings in the calling function, but
-                    there is need to abort the program because of this. */
   }
 
-  dlgEditWorld = GTK_WIDGET(gtk_builder_get_object(world->ui_builder,
-                                                   "dlgEditWorld"));
+  world->dlgEditWorld = GTK_WIDGET(gtk_builder_get_object(world->ui_builder,
+                                                          "dlgEditWorld"));
+  gtk_window_set_transient_for(GTK_WINDOW(world->dlgEditWorld),
+                               GTK_WINDOW(wndMain));
+  gtk_dialog_set_default_response(GTK_DIALOG(world->dlgEditWorld),
+                                  GTK_RESPONSE_OK);
 
-  gtk_dialog_set_default_response(GTK_DIALOG(dlgEditWorld), GTK_RESPONSE_OK);
+  stack = GTK_STACK(gtk_builder_get_object(world->ui_builder, "stackWEPanel"));
 
-  notebook = GTK_NOTEBOOK(gtk_builder_get_object(world->ui_builder,
-                                                 "ntbkWEPanel"));
-  gtk_notebook_set_show_tabs(notebook, FALSE);
-
-  model = create_model(notebook, world, world->ui_builder);
-  g_object_set_data(G_OBJECT(model), "notebookptr", notebook);
+  model = create_model(stack, world, world->ui_builder);
+  g_object_set_data(G_OBJECT(model), "stackptr", stack);
   treeView = GTK_TREE_VIEW(gtk_builder_get_object(world->ui_builder,
                                                   "treeViewWE"));
   gtk_tree_view_set_model(treeView, GTK_TREE_MODEL(model));
@@ -215,16 +211,14 @@ create_edit_world_dialog(World *world, GtkWindow *parent)
   gtk_tree_selection_select_iter(selection, &iter);
 
   gtk_builder_connect_signals(world->ui_builder, world);
-
-  return dlgEditWorld;
 }
 
 
 static
 GtkTreeStore *
-create_model(GtkNotebook *notebook,
-             World       *world,
-             GtkBuilder  *ui_builder)
+create_model(GtkStack   *stack,
+             World      *world,
+             GtkBuilder *ui_builder)
 {
   GtkTreeStore *model;
   GObject      *panel;
@@ -252,7 +246,7 @@ create_model(GtkNotebook *notebook,
   gtk_tree_store_append(model, &iterDisplay, NULL);
   display_panel = new_descriptive_panel(_("Display"),
                                         _("Here you can set options to configure the appearance of KildClient."));
-  gtk_notebook_append_page(notebook, display_panel, NULL);
+  gtk_stack_add_named(stack, display_panel, "we_panel_display");
   gtk_tree_store_set(model, &iterDisplay,
                      COLUMN_NAME, _("Display"),
                      COLUMN_WIDGET, display_panel,
@@ -262,7 +256,7 @@ create_model(GtkNotebook *notebook,
   panel = get_we_mainwindow_tab(ui_builder);
   fill_we_mainwindow_tab(world, ui_builder);
   gtk_tree_store_set(model, &iter,
-                     COLUMN_NAME, _("Main Window"),
+                     COLUMN_NAME, _("Main window"),
                      COLUMN_WIDGET, panel,
                      -1);
 
@@ -278,7 +272,7 @@ create_model(GtkNotebook *notebook,
   panel = get_we_statusbar_tab(ui_builder);
   fill_we_statusbar_tab(world, ui_builder);
   gtk_tree_store_set(model, &iter,
-                     COLUMN_NAME, _("Status Bar"),
+                     COLUMN_NAME, _("Status bar"),
                      COLUMN_WIDGET, panel,
                      -1);
 
@@ -302,7 +296,7 @@ create_model(GtkNotebook *notebook,
     gtk_tree_store_append(model, &iterAutomation, NULL);
     display_panel = new_descriptive_panel(_("Automation"),
                                           _("Here you can set options to configure the automation features of KildClient, such as triggers, aliases, plugins, etc."));
-    gtk_notebook_append_page(notebook, display_panel, NULL);
+    gtk_stack_add_named(stack, display_panel, "we_panel_automation");
     gtk_tree_store_set(model, &iterAutomation,
                        COLUMN_NAME, _("Automation"),
                        COLUMN_WIDGET, display_panel,
@@ -326,8 +320,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_triggers_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_triggers");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -337,8 +331,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_aliases_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_aliases");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -348,8 +342,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_macros_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_macros");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -359,8 +353,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_timers_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_timers");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -370,8 +364,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_hooks_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_hooks");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -381,8 +375,8 @@ create_model(GtkNotebook *notebook,
 
     gtk_tree_store_append(model, &iter, &iterAutomation);
     panel = get_we_vars_tab(world);
-    gtk_notebook_append_page(notebook, GTK_WIDGET(panel), NULL);
-    /* Let the notebook own the panel, removing the ref added when it
+    gtk_stack_add_named(stack, GTK_WIDGET(panel), "we_panel_vars");
+    /* Let the stack own the panel, removing the ref added when it
        was created. */
     g_object_unref(panel);
     gtk_tree_store_set(model, &iter,
@@ -399,14 +393,6 @@ create_model(GtkNotebook *notebook,
                      COLUMN_WIDGET, panel,
                      -1);
 
-  gtk_tree_store_append(model, &iter, NULL);
-  panel = get_we_misc_tab(ui_builder);
-  fill_we_misc_tab(world, ui_builder);
-  gtk_tree_store_set(model, &iter,
-                     COLUMN_NAME, _("Miscellaneous"),
-                     COLUMN_WIDGET, panel,
-                     -1);
-
   gtk_tree_store_append(model, &iter, NULL);
   panel = get_we_advanced_tab(world, ui_builder);
   fill_we_advanced_tab(world, ui_builder);
@@ -426,14 +412,13 @@ list_selection_changed_cb(GtkTreeSelection *selection,
 {
   GtkTreeModel *model;
   GtkTreeIter   iter;
-  GtkWidget    *notebook;
+  GtkStack     *stack;
 
   if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
     GtkTreePath *path;
     GtkWidget   *panel;
-    int          pageNum;
 
-    notebook = g_object_get_data(G_OBJECT(model), "notebookptr");
+    stack = g_object_get_data(G_OBJECT(model), "stackptr");
 
     path = gtk_tree_model_get_path(model, &iter);
     gtk_tree_view_expand_row(GTK_TREE_VIEW(data), path, FALSE);
@@ -442,8 +427,7 @@ list_selection_changed_cb(GtkTreeSelection *selection,
     gtk_tree_model_get(model, &iter,
                        COLUMN_WIDGET, &panel,
                        -1);
-    pageNum = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), panel);
-    gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), pageNum);
+    gtk_stack_set_visible_child(stack, panel);
   }
 }
 
@@ -457,18 +441,20 @@ new_descriptive_panel(const char *title, const char *message)
   gchar     *temp;
 
   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+  gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
-  temp = g_strdup_printf("<span weight=\"bold\" size=\"larger\">%s</span>",
-                         title);
+  temp = g_strdup_printf("<b>%s</b>", title);
   label = gtk_label_new(NULL);
-  gtk_label_set_markup(GTK_LABEL(label),
-                       temp);
+  gtk_label_set_markup(GTK_LABEL(label), temp);
   g_free(temp);
-  gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 8);
+  gtk_widget_set_halign(label, GTK_ALIGN_START);
+  gtk_widget_set_valign(label, GTK_ALIGN_START);
+  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
   label = gtk_label_new(message);
-  gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+  gtk_widget_set_margin_start(label, 16);
+  gtk_widget_set_halign(label, GTK_ALIGN_START);
+  gtk_widget_set_valign(label, GTK_ALIGN_START);
   gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
