@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include "libintl-wrapper.h"
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#ifdef __WIN32__
+#ifdef __MINGW32__
 #  include <windows.h>
 #  include <shellapi.h>
 #endif
@@ -51,6 +51,7 @@ static GdkCursor *regular_cursor = NULL;
 /***********************
  * Function prototypes *
  ***********************/
+static void      create_css_provider(WorldGUI *gui);
 static void      combo_changed_cb(SimoComboBox *combo, gpointer data);
 static void      combo_poped_cb(SimoComboBox *combo, gpointer data);
 static void      combo_closed_cb(SimoComboBox *combo, gpointer data);
@@ -61,7 +62,6 @@ static gboolean  keypress_cb(GtkWidget   *widget,
                              gpointer    data);
 static void      text_changed_cb(SimoComboBox *cmb, gpointer data);
 static void      cursor_moved_cb(GtkTextBuffer *buffer,
-                                 GtkTextIter   *iter,
                                  GtkTextMark   *mark,
                                  gpointer       data);
 static gboolean  completion_function(GtkEntryCompletion *completion,
@@ -132,20 +132,21 @@ world_gui_new(gboolean is_for_mud)
   GtkTreeViewColumn *column;
   GtkCellRenderer   *renderer;
 
-  PangoFontDescription *fontDesc;
-  GtkTextIter           end_iter;
-  GdkRGBA               black = { 0,    0,    0,    1 };
-  GdkRGBA               blue  = { 0.58, 0.79, 0.93, 1 };
+  GtkTextIter end_iter;
 
 
   /* First, create the cursors if this is the first run */
   if (!hand_cursor) {
-    hand_cursor = gdk_cursor_new(GDK_HAND2);
-    regular_cursor = gdk_cursor_new(GDK_XTERM);
+    hand_cursor = gdk_cursor_new_for_display(gdk_display_get_default(),
+                                             GDK_HAND2);
+    regular_cursor = gdk_cursor_new_for_display(gdk_display_get_default(),
+                                                GDK_XTERM);
   }
 
   gui = g_new0(WorldGUI, 1);
 
+  create_css_provider(gui);
+
   gui->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
   g_object_set_data(G_OBJECT(gui->vbox), "gui", gui);
 
@@ -153,8 +154,14 @@ world_gui_new(gboolean is_for_mud)
   gtk_scrolled_window_set_policy(gui->scrolled_win,
                                  GTK_POLICY_AUTOMATIC,
                                  GTK_POLICY_ALWAYS);
+  /* With the default (on), scroll-to-end does not work with GTK+ >= 3.13 */
+  g_object_set(gtk_widget_get_settings(GTK_WIDGET(gui->scrolled_win)),
+               "gtk-enable-animations", FALSE,
+               NULL);
 
   gui->txtView = GTK_TEXT_VIEW(gtk_text_view_new());
+  add_css_provider_and_class(GTK_WIDGET(gui->txtView),
+                             gui->css_provider, "mud-output");
   gtk_text_view_set_editable(gui->txtView, FALSE);
   gui->txtBuffer = gtk_text_view_get_buffer(gui->txtView);
   /* Store a mark at the end, to allow scrolling to it */
@@ -179,6 +186,8 @@ world_gui_new(gboolean is_for_mud)
                                    GTK_POLICY_ALWAYS);
     gui->txtViewScroll
       = GTK_TEXT_VIEW(gtk_text_view_new_with_buffer(gui->txtBuffer));
+    add_css_provider_and_class(GTK_WIDGET(gui->txtViewScroll),
+                               gui->css_provider, "mud-output");
     gtk_text_view_set_editable(gui->txtViewScroll, FALSE);
     gtk_container_add(GTK_CONTAINER(gui->scrwinScroll),
                       GTK_WIDGET(gui->txtViewScroll));
@@ -186,7 +195,7 @@ world_gui_new(gboolean is_for_mud)
     /* Create split pane */
     gui->split_pane = GTK_PANED(gtk_paned_new(GTK_ORIENTATION_VERTICAL));
     gtk_paned_pack1(gui->split_pane, GTK_WIDGET(gui->scrwinScroll), FALSE, TRUE);
-    gtk_paned_pack2(gui->split_pane, GTK_WIDGET(gui->scrolled_win), TRUE, TRUE);
+    gtk_paned_pack2(gui->split_pane, GTK_WIDGET(gui->scrolled_win), TRUE, FALSE);
     /* For some reason, we cannot set to 0 directly. */
     g_idle_add(set_split_to_zero, gui);
 
@@ -231,7 +240,7 @@ world_gui_new(gboolean is_for_mud)
     gtk_box_pack_start(GTK_BOX(gui->search_box), gui->txtSearchTerm,
                        FALSE, FALSE, 0);
 
-    gui->btnFindNext = gtk_button_new_with_label(_("Find Next"));
+    gui->btnFindNext = gtk_button_new_with_mnemonic(_("Find n_ext"));
     gtk_button_set_relief(GTK_BUTTON(gui->btnFindNext), GTK_RELIEF_NONE);
     g_signal_connect(G_OBJECT(gui->btnFindNext), "clicked",
                      G_CALLBACK(find_next_cb), gui);
@@ -263,6 +272,10 @@ world_gui_new(gboolean is_for_mud)
   if (is_for_mud) {
     /* The full-featured SimoComboBox */
     gui->cmbEntry = SIMO_COMBO_BOX(simo_combo_box_new());
+    add_css_provider_and_class(simo_combo_box_get_single_line_widget(gui->cmbEntry),
+                               gui->css_provider, "input");
+    add_css_provider_and_class(simo_combo_box_get_multi_line_widget(gui->cmbEntry),
+                               gui->css_provider, "input");
     g_signal_connect(G_OBJECT(gui->cmbEntry), "size-changed",
                      G_CALLBACK(n_lines_changed_cb), gui);
     g_signal_connect(G_OBJECT(gui->cmbEntry), "clicked",
@@ -273,13 +286,15 @@ world_gui_new(gboolean is_for_mud)
                      G_CALLBACK(combo_closed_cb), gui);
     g_signal_connect(G_OBJECT(gui->cmbEntry), "activate",
                      G_CALLBACK(activate_cb), gui);
-    g_signal_connect(G_OBJECT(gui->cmbEntry->txtview), "key-press-event",
+    g_signal_connect(G_OBJECT(simo_combo_box_get_multi_line_widget(SIMO_COMBO_BOX(gui->cmbEntry))),
+                     "key-press-event",
                      G_CALLBACK(keypress_cb), gui);
-    g_signal_connect(G_OBJECT(gui->cmbEntry->entry), "key-press-event",
+    g_signal_connect(G_OBJECT(simo_combo_box_get_single_line_widget(SIMO_COMBO_BOX(gui->cmbEntry))),
+                     "key-press-event",
                      G_CALLBACK(keypress_cb), gui);
     g_signal_connect(G_OBJECT(gui->cmbEntry), "changed",
                      G_CALLBACK(text_changed_cb), gui);
-    g_signal_connect(G_OBJECT(gui->cmbEntry->txtbuffer), "mark-set",
+    g_signal_connect(G_OBJECT(gui->cmbEntry), "mark-set",
                      G_CALLBACK(cursor_moved_cb), gui);
     gtk_box_pack_start(GTK_BOX(gui->commandArea), GTK_WIDGET(gui->cmbEntry),
                        TRUE, TRUE, 0);
@@ -295,9 +310,10 @@ world_gui_new(gboolean is_for_mud)
     simo_combo_box_set_combo_column(gui->cmbEntry, column);
   } else {
     /* Just a GtkEntry */
-    gui->txtEntry = GTK_ENTRY(gtk_entry_new());
-    gtk_box_pack_start(GTK_BOX(gui->commandArea), GTK_WIDGET(gui->txtEntry),
-                       TRUE, TRUE, 0);
+    GtkWidget *widget = gtk_entry_new();
+    add_css_provider_and_class(widget, gui->css_provider, "input");
+    gtk_box_pack_start(GTK_BOX(gui->commandArea), widget, TRUE, TRUE, 0);
+    gui->txtEntry = GTK_ENTRY(widget);
   }
   gtk_box_pack_start(GTK_BOX(gui->vbox), gui->commandArea, FALSE, FALSE, 0);
 
@@ -364,7 +380,7 @@ world_gui_new(gboolean is_for_mud)
     btnClose = gtk_button_new_from_icon_name("window-close",
                                              GTK_ICON_SIZE_BUTTON);
     /* Make the button smaller. (Taken from gedit code) */
-    gtk_button_set_focus_on_click(GTK_BUTTON(btnClose), FALSE);
+    gtk_widget_set_focus_on_click(btnClose, FALSE);
     gtk_button_set_relief(GTK_BUTTON(btnClose), GTK_RELIEF_NONE);
 
     g_signal_connect(G_OBJECT(btnClose), "clicked",
@@ -372,27 +388,6 @@ world_gui_new(gboolean is_for_mud)
     gtk_box_pack_start(GTK_BOX(gui->hboxTab), btnClose,
                        FALSE, FALSE, 0);
 
-    /* The color and font will be changed later to the colors and font
-       of the opened world, but we set the background to black so that is
-       appears black while the world is being selected, and the font to a
-       default font so that the size can be calculated correctly. */
-    fontDesc = pango_font_description_from_string(DEFAULT_TERMINAL_FONT);
-    gtk_widget_override_font(GTK_WIDGET(gui->txtView), fontDesc);
-    gtk_widget_override_font(GTK_WIDGET(gui->txtViewScroll), fontDesc);
-    pango_font_description_free(fontDesc);
-    gtk_widget_override_background_color(GTK_WIDGET(gui->txtView),
-                                         GTK_STATE_FLAG_NORMAL, &black);
-    gtk_widget_override_background_color(GTK_WIDGET(gui->txtView),
-                                         GTK_STATE_FLAG_SELECTED, &blue);
-    gtk_widget_override_color(GTK_WIDGET(gui->txtView),
-                              GTK_STATE_FLAG_SELECTED, &black);
-    gtk_widget_override_background_color(GTK_WIDGET(gui->txtViewScroll),
-                                         GTK_STATE_FLAG_NORMAL, &black);
-    gtk_widget_override_background_color(GTK_WIDGET(gui->txtViewScroll),
-                                         GTK_STATE_FLAG_SELECTED, &blue);
-    gtk_widget_override_color(GTK_WIDGET(gui->txtViewScroll),
-                              GTK_STATE_FLAG_SELECTED, &black);
-
     /* Detect resizes */
     g_signal_connect(G_OBJECT(gui->txtView), "size-allocate",
                      G_CALLBACK(textview_size_allocate_cb), gui);
@@ -428,14 +423,17 @@ world_gui_new(gboolean is_for_mud)
     gui->statusbar_box = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4));
 
     gui->lblStatus = GTK_LABEL(gtk_label_new(_("KildClient ready")));
-    gtk_misc_set_alignment(GTK_MISC(gui->lblStatus), 0, 0.5);
+    add_css_provider_and_class(GTK_WIDGET(gui->lblStatus),
+                               gui->css_provider,
+                               "status-bar");
+    gtk_widget_set_halign(GTK_WIDGET(gui->lblStatus), GTK_ALIGN_START);
     gtk_label_set_single_line_mode(gui->lblStatus, TRUE);
     gtk_label_set_ellipsize(gui->lblStatus, PANGO_ELLIPSIZE_END);
     gtk_box_pack_start(gui->statusbar_box, GTK_WIDGET(gui->lblStatus),
                        TRUE, TRUE, 0);
 
     gui->lblLines = GTK_LABEL(gtk_label_new(_("0 lines")));
-    gtk_misc_set_alignment(GTK_MISC(gui->lblLines), 0, 0.5);
+    gtk_widget_set_halign(GTK_WIDGET(gui->lblLines), GTK_ALIGN_START);
     gtk_label_set_single_line_mode(gui->lblLines, TRUE);
     frame = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
@@ -444,7 +442,7 @@ world_gui_new(gboolean is_for_mud)
                        FALSE, FALSE, 0);
 
     gui->lblTime = GTK_LABEL(gtk_label_new(NULL));
-    gtk_misc_set_alignment(GTK_MISC(gui->lblTime), 0, 0.5);
+    gtk_widget_set_halign(GTK_WIDGET(gui->lblTime), GTK_ALIGN_START);
     gtk_label_set_single_line_mode(gui->lblTime, TRUE);
     frame = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
@@ -466,6 +464,14 @@ world_gui_new(gboolean is_for_mud)
 }
 
 
+void
+create_css_provider(WorldGUI *gui)
+{
+  gui->css_provider = gtk_css_provider_new();
+  configure_css(gui, default_world);
+}
+
+
 void
 world_gui_size_textview(WorldGUI *gui)
 {
@@ -522,6 +528,8 @@ worldgui_determine_supported_chars(WorldGUI *gui)
 void
 free_world_gui(WorldGUI *gui)
 {
+  g_object_unref(gui->css_provider);
+
   if (gui->prune_timeout_id) {
     g_source_remove(gui->prune_timeout_id);
   }
@@ -732,7 +740,6 @@ keypress_cb(GtkWidget   *widget,
       newval = gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size(adjustment);
     }
     gtk_adjustment_set_value(adjustment, newval);
-    gtk_adjustment_changed(adjustment);
     return TRUE;
 
   case GDK_KEY_End:
@@ -741,7 +748,6 @@ keypress_cb(GtkWidget   *widget,
       adjustment = gtk_scrolled_window_get_vadjustment(gui->scrolled_win);
       gtk_adjustment_set_value(adjustment,
                                gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size(adjustment));
-      gtk_adjustment_changed(adjustment);
       return TRUE;
     }
     break;
@@ -782,7 +788,6 @@ text_changed_cb(SimoComboBox *cmb, gpointer data)
 static
 void
 cursor_moved_cb(GtkTextBuffer *buffer,
-                GtkTextIter   *iter,
                 GtkTextMark   *mark,
                 gpointer       data)
 {
@@ -934,26 +939,10 @@ clear_button_cb(GtkButton *button, gpointer data)
 void
 configure_gui(WorldGUI *gui, World *world)
 {
-  PangoFontDescription *fontDesc;
-  GtkEntryCompletion   *completion;
-  GtkCellRenderer      *renderer;
+  GtkEntryCompletion *completion;
+  GtkCellRenderer    *renderer;
 
-  fontDesc = pango_font_description_from_string(world->terminalfont);
-  gtk_widget_override_font(GTK_WIDGET(gui->txtView), fontDesc);
-  gtk_widget_override_font(GTK_WIDGET(gui->txtViewScroll), fontDesc);
-  pango_font_description_free(fontDesc);
-  fontDesc = pango_font_description_from_string(world->entryfont);
-  if (gui->world) {
-    simo_combo_box_set_entry_font(gui->cmbEntry, fontDesc);
-  } else {
-    gtk_widget_override_font(GTK_WIDGET(gui->txtEntry), fontDesc);
-  }
-  pango_font_description_free(fontDesc);
-  if (gui->lblStatus) {
-    fontDesc = pango_font_description_from_string(world->statusfont);
-    gtk_widget_override_font(GTK_WIDGET(gui->lblStatus), fontDesc);
-    pango_font_description_free(fontDesc);
-  }
+  configure_css(gui, world);
 
   gtk_text_view_set_wrap_mode(gui->txtView,
                               world->wrap
@@ -1012,10 +1001,60 @@ configure_gui(WorldGUI *gui, World *world)
 }
 
 
+void
+configure_css(WorldGUI *gui, World *world)
+{
+  gchar *terminalfont;
+  gchar *entryfont;
+  gchar *statusfont;
+
+  terminalfont = pango_font_to_css(world->terminalfont);
+  entryfont    = pango_font_to_css(world->entryfont);
+  statusfont   = pango_font_to_css(world->statusfont);
+
+  gchar *css = g_strdup_printf(
+    ".mud-output text {"
+    "  background-color: %s;"
+    "  color: %s;"
+    "}"
+    ".mud-output {"
+    "  %s;"
+    "}"
+
+    ".link-popup-menu {" /* Use system font in the popup menu, */
+    "  font: initial;"   /* instead of the mud output font. */
+    "}"
+
+    ".mud-output text selection {"
+    "  background-color: #94c9ed;"
+    "  color: #000000;"
+    "}"
+
+    ".input {"
+    "  %s;"
+    "}"
+
+    ".status-bar {"
+    "  %s;"
+    "}",
+    gdk_rgba_to_string(world->defback),
+    gdk_rgba_to_string(world->deffore),
+    terminalfont,
+    entryfont,
+    statusfont);
+
+  gtk_css_provider_load_from_data(gui->css_provider, css, -1, NULL);
+
+  g_free(terminalfont);
+  g_free(entryfont);
+  g_free(statusfont);
+  g_free(css);
+}
+
+
 void
 worldgui_configure_spell(WorldGUI *gui)
 {
-#ifdef HAVE_GTKSPELL
   GError *error = NULL;
 
   simo_combo_box_set_spell(gui->cmbEntry,
@@ -1025,9 +1064,6 @@ worldgui_configure_spell(WorldGUI *gui)
     ansitextview_append_stringf(gui,_("Error setting spell checker: %s\n"), error->message);
     g_error_free(error);
   }
-#else
-  ansitextview_append_string_nl(gui, _("Spell checking support not included in this build."));
-#endif
 }
 
 
@@ -1103,6 +1139,8 @@ act_if_link(WorldGUI *gui, GtkTextIter *iter,
     gtk_builder_connect_signals(ui_builder, matched_url);
 
     gtk_menu_attach_to_widget(mnuPopupURL, widget, NULL);
+    add_css_provider_and_class(GTK_WIDGET(mnuPopupURL), gui->css_provider,
+                               "link-popup-menu");
     gtk_menu_popup(mnuPopupURL, NULL, NULL, NULL, NULL,
                    event->button, event->time);
     g_object_unref(ui_builder);
@@ -1112,7 +1150,7 @@ act_if_link(WorldGUI *gui, GtkTextIter *iter,
 }
 
 
-#ifndef __WIN32__
+#ifndef __MINGW32__
 void
 menu_url_open(GtkMenuItem *menu, char *url)
 {
@@ -1125,7 +1163,7 @@ menu_url_open(GtkMenuItem *menu, char *url)
   g_free(to_run);
   g_free(url);
 }
-#else /* defined __WIN32__ */
+#else /* defined __MINGW32__ */
 void
 menu_url_open(GtkMenuItem *menu, char *url)
 {
