@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,8 +96,6 @@ typedef enum {
   KC_TIMER,
   KC_VARIABLES,
   KC_VARIABLE,
-  KC_HOOKSV1,
-  KC_HOOKV1,
   KC_HOOKSV2,
   KC_HOOKLISTV2,
   KC_HOOKV2,
@@ -135,7 +133,6 @@ typedef struct WorldParser_s WorldParser;
 /***********************
  * Function prototypes *
  ***********************/
-static void create_default_world(void);
 static void world_allocate_space_for_colors(World *world);
 static void xml_start_element(GMarkupParseContext *context,
                               const gchar         *element_name,
@@ -230,10 +227,6 @@ create_new_world(gboolean load_defaults)
     return world;
   }
 
-  if (!default_world) {
-    create_default_world();
-  }
-
   /* Create pbuffer */
   world->pbuffer = (guchar *) g_malloc(MAX_BUFFER);
   world->pbuf_alloc_size = MAX_BUFFER;
@@ -285,6 +278,7 @@ create_new_world(gboolean load_defaults)
     = g_strdup(default_world->flood_prevention_command);
   world->repeat_count             = 1;
 
+  world->log_file_name  = g_strdup(default_world->log_file_name);
   world->log_timeformat = g_strdup(default_world->log_timeformat);
   world->log_add_time   = default_world->log_add_time;
   world->log_autostart  = default_world->log_autostart;
@@ -310,7 +304,6 @@ create_new_world(gboolean load_defaults)
 }
 
 
-static
 void
 create_default_world(void)
 {
@@ -830,7 +823,7 @@ load_world_from_file(const char *file,
   if (!fp) {
     g_set_error(error,
                 G_FILE_ERROR, G_FILE_ERROR_NOENT,
-                _("Could not open file: %s"), g_strerror(errno));
+                _("Could not open file '%s': %s"), file, g_strerror(errno));
     return FALSE;
   }
 
@@ -1240,8 +1233,6 @@ xml_start_element(GMarkupParseContext *context,
       parser->state = KC_TIMERS;
     } else if (strcmp(element_name, "variables") == 0) {
       parser->state = KC_VARIABLES;
-    } else if (strcmp(element_name, "hooks") == 0) {
-      parser->state = KC_HOOKSV1;
     } else if (strcmp(element_name, "hooksv2") == 0) {
       parser->state = KC_HOOKSV2;
     } else if (strcmp(element_name, "protocols") == 0) {
@@ -1530,30 +1521,6 @@ xml_start_element(GMarkupParseContext *context,
     }
     break;
 
-  case KC_HOOKSV1: // Kept for backward compatibility
-    if (strcmp(element_name, "hook") == 0) {
-      parser->state = KC_HOOKV1;
-      parser->previous_state = KC_HOOKSV1;
-      if (parser->forWorldSelector) {
-        break;
-      }
-
-      parser->currText = &parser->currHookAction;
-
-      while (*attribute_names) {
-        if (strcmp(*attribute_names, "for") == 0) {
-          parser->currHookTrigger = g_strdup(*attribute_values);
-        } else {
-          xml_error_unknown_attribute(error, *attribute_names, context);
-        }
-        ++attribute_names;
-        ++attribute_values;
-      }
-    } else {
-      xml_error_invalid_inside(error, context);
-    }
-    break;
-
   case KC_HOOKSV2:
     if (strcmp(element_name, "hooklistv2") == 0) {
       parser->state = KC_HOOKLISTV2;
@@ -1740,7 +1707,6 @@ xml_end_element(GMarkupParseContext *context,
   case KC_MACROS:
   case KC_TIMERS:
   case KC_VARIABLES:
-  case KC_HOOKSV1:
   case KC_HOOKSV2:
   case KC_PROTOCOLS:
   case KC_KEEP_ALIVE:
@@ -1837,7 +1803,6 @@ xml_end_element(GMarkupParseContext *context,
     parser->state = KC_VARIABLES;
     break;
 
-  case KC_HOOKV1:
   case KC_HOOKV2:
     if (!parser->forWorldSelector) {
       connect_hook(parser->world,
@@ -1846,9 +1811,6 @@ xml_end_element(GMarkupParseContext *context,
                    parser->currHookAction,
                    parser->currHookName,
                    parser->currHookEnabled);
-      if (parser->state == KC_HOOKV1) {
-        g_free(parser->currHookTrigger);
-      }
       parser->currHookName = NULL;
     }
     parser->state = parser->previous_state;
@@ -1925,7 +1887,6 @@ xml_text(GMarkupParseContext *context,
   case KC_SUBSTITUTION:
   case KC_TIMER:
   case KC_VARIABLE:
-  case KC_HOOKV1:
   case KC_HOOKV2:
     copy_text(parser->currText, text, text_len);
     break;
@@ -2360,16 +2321,9 @@ save_world_to_file(World *world)
   if (!g_file_set_contents(world->file,
                            file_contents->str, file_contents->len,
                            &error)) {
-    GtkWidget *dlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                            GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_CLOSE,
-                                            _("Could not open file '%s': %s"),
-                                            world->file,
-                                            error->message);
-    gtk_window_set_title(GTK_WINDOW(dlg), _("KildClient Error"));
-    gtk_dialog_run(GTK_DIALOG(dlg));
-    gtk_widget_destroy(dlg);
+    kc_error_dialog(GTK_WINDOW(wndMain),
+                    _("Could not open file '%s': %s"),
+                    world->file, error->message);
   }
   g_string_free(file_contents, TRUE);
 }
