@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
+ * Copyright (C) 2004-2016 Eduardo M Kalinowski <eduardo@kalinowski.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #include <string.h>
 #include <unistd.h>
-#ifndef __WIN32__
+#ifndef __MINGW32__
 #  include <glob.h>
 #else
 #  include <windows.h>
@@ -131,16 +131,9 @@ get_world_to_connect()
                              -1);
           success = load_world_from_file(file, world, FALSE, &error);
           if (!success) {
-            GtkWidget *msgdlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                       GTK_MESSAGE_ERROR,
-                                                       GTK_BUTTONS_CLOSE,
-                                                       _("Could not load world from file '%s': %s"),
-                                                       file,
-                                                       error->message);
-            gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Error"));
-            gtk_dialog_run(GTK_DIALOG(msgdlg));
-            gtk_widget_destroy(msgdlg);
+            kc_error_dialog(GTK_WINDOW(wndMain),
+                            _("Could not load world from file '%s': %s"),
+                            file, error->message);
             free_world(world);
             world = NULL;
           } else {
@@ -278,7 +271,7 @@ create_saved_worlds_model(GtkTreeIter **last_open_iter)
 }
 
 
-#ifndef __WIN32__
+#ifndef __MINGW32__
 static
 void
 fill_saved_worlds_model(GtkTreeStore *model, GtkTreeIter **last_open_iter)
@@ -290,17 +283,17 @@ fill_saved_worlds_model(GtkTreeStore *model, GtkTreeIter **last_open_iter)
   kilddir = get_kildclient_directory_path();;
   globstr = g_strdup_printf("%s/*.wrl", kilddir);
 
-  if (glob(globstr, GLOB_ERR | GLOB_NOSORT,
-           0, &globbuf) == 0 && globbuf.gl_pathc) {
-    char *file;
-
-    while ((file = *globbuf.gl_pathv++)) {
-      add_saved_worlds_model_entry_from_file(model, file, last_open_iter);
+  if (glob(globstr, GLOB_ERR | GLOB_NOSORT, NULL, &globbuf) == 0) {
+    int i;
+    for (i = 0; i < globbuf.gl_pathc; ++i) {
+      add_saved_worlds_model_entry_from_file(model,
+                                             globbuf.gl_pathv[i],
+                                             last_open_iter);
     }
   }
 
   g_free(globstr);
-  /* globfree(&globbuf); */
+  globfree(&globbuf);
 }
 #else
 static
@@ -542,7 +535,7 @@ get_world_from_cmdline(const gchar *cmdline)
 }
 
 
-#ifndef __WIN32__
+#ifndef __MINGW32__
 static
 char *
 try_find_world_from_name(const gchar *name)
@@ -555,17 +548,15 @@ try_find_world_from_name(const gchar *name)
   kilddir = get_kildclient_directory_path();
   globstr = g_strdup_printf("%s/*.wrl", kilddir);
 
-  if (glob(globstr, GLOB_ERR | GLOB_NOSORT,
-           0, &globbuf) == 0 && globbuf.gl_pathc) {
-    char *file;
-
-    while (!result && (file = *globbuf.gl_pathv++)) {
-      result = compare_world_from_name(file, name);
+  if (glob(globstr, GLOB_ERR | GLOB_NOSORT, 0, &globbuf) == 0) {
+    int i;
+    for (i = 0; !result && i < globbuf.gl_pathc; ++i) {
+      result = compare_world_from_name(globbuf.gl_pathv[i], name);
     }
   }
 
   g_free(globstr);
-  /* globfree(&globbuf); */
+  globfree(&globbuf);
   return result;
 }
 #else
@@ -682,16 +673,9 @@ add_edit_buttons_cb(GtkButton *btn, gpointer data)
     world = create_new_world(FALSE);
 
     if (!load_world_from_file(file, world, FALSE, &error)) {
-      GtkWidget *msgdlg = gtk_message_dialog_new(GTK_WINDOW(wndMain),
-                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                 GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_CLOSE,
-                                                 _("Could not load world from file '%s': %s"),
-                                                 file,
-                                                 error->message);
-      gtk_window_set_title(GTK_WINDOW(msgdlg), _("KildClient Error"));
-      gtk_dialog_run(GTK_DIALOG(msgdlg));
-      gtk_widget_destroy(msgdlg);
+      kc_error_dialog(GTK_WINDOW(wndMain),
+                      _("Could not load world from file '%s': %s"),
+                      file, error->message);
       g_free(world);
       return;
     }
@@ -760,8 +744,7 @@ delete_button_cb(GtkButton *btn, gpointer data)
 
   msg = g_strdup_printf("world '%s'", name);
   msgdlg = we_guied_confirm_delete_dialog_new(GTK_WINDOW(wndMain),
-                                              1,
-                                              msg, "");
+                                              msg, 1);
   g_free(msg);
 
   if (gtk_dialog_run(GTK_DIALOG(msgdlg)) == GTK_RESPONSE_YES) {
@@ -810,15 +793,15 @@ disconnected_msgbox(gchar *msg, gboolean can_offline)
   gtk_window_set_title(GTK_WINDOW(dlg), _("Disconnected"));
   if (can_offline) {
     gtk_dialog_add_buttons(GTK_DIALOG(dlg),
-                           _("Reconnect"), RESP_RECONNECT,
-                           _("Connect to another world"), RESP_OTHER,
-                           _("Offline"), RESP_OFFLINE,
+                           _("_Reconnect"), RESP_RECONNECT,
+                           _("Connect to _another world"), RESP_OTHER,
+                           _("_Offline"), RESP_OFFLINE,
                            _("_Close"),GTK_RESPONSE_CLOSE,
                            NULL);
   } else {
     gtk_dialog_add_buttons(GTK_DIALOG(dlg),
-                           _("Reconnect"), RESP_RECONNECT,
-                           _("Connect to another world"), RESP_OTHER,
+                           _("_Reconnect"), RESP_RECONNECT,
+                           _("Connect to _another world"), RESP_OTHER,
                            _("_Close"), GTK_RESPONSE_CLOSE,
                            NULL);
   }
